"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/** @jsx jsx */
var core_1 = require("@emotion/core");
var React = tslib_1.__importStar(require("react"));
var alert_1 = tslib_1.__importDefault(require("@reach/alert"));
var Text_1 = require("./Text");
var IconButton_1 = require("./IconButton");
var prop_types_1 = tslib_1.__importDefault(require("prop-types"));
var Providers_1 = require("./Theme/Providers");
var IconWrapper_1 = require("./IconWrapper");
var Icons_1 = require("./Icons");
var alertIntentions = function (theme) { return ({
    info: theme.colors.intent.none,
    success: theme.colors.intent.success,
    question: theme.colors.intent.primary,
    danger: theme.colors.intent.danger,
    warning: theme.colors.intent.warning
}); };
var icons = {
    info: core_1.jsx(Icons_1.IconInfo, null),
    success: core_1.jsx(Icons_1.IconCheckCircle, null),
    warning: core_1.jsx(Icons_1.IconAlertCircle, null),
    danger: core_1.jsx(Icons_1.IconAlertOctagon, null),
    question: core_1.jsx(Icons_1.IconHelpCircle, null)
};
/**
 * Use an alert to inform users of important information.
 * To display an alert in a toast notification, use the toast module.
 */
exports.Alert = function (_a) {
    var children = _a.children, title = _a.title, id = _a.id, subtitle = _a.subtitle, component = _a.component, _b = _a.elevation, elevation = _b === void 0 ? "xs" : _b, onRequestClose = _a.onRequestClose, _c = _a.intent, intent = _c === void 0 ? "info" : _c, other = tslib_1.__rest(_a, ["children", "title", "id", "subtitle", "component", "elevation", "onRequestClose", "intent"]);
    var theme = Providers_1.useTheme();
    var intentions = React.useMemo(function () { return alertIntentions(theme); }, [theme]);
    var dark = theme.colors.mode === "dark";
    var color = intentions[intent];
    var accent = dark ? color.light : color.base;
    if (dark && intent === "info") {
        accent = color.light;
    }
    var icon = icons[intent];
    var contents = title ? (core_1.jsx("div", { className: "Alert__title", css: { display: "flex", alignItems: "flex-start" } },
        core_1.jsx("div", { css: { flex: "0 0 auto", marginTop: "2px" } },
            core_1.jsx(IconWrapper_1.IconWrapper, { size: "md", color: accent }, icon)),
        core_1.jsx("div", { className: "Alert__text-content", css: { marginLeft: theme.spaces.md } },
            core_1.jsx(Text_1.Text, { className: "Alert__title-text", id: id, css: { margin: 0 }, variant: "h6" }, title),
            subtitle && (core_1.jsx(Text_1.Text, { className: "Alert__title-subtitle", muted: true, css: {
                    fontSize: theme.fontSizes[0]
                } }, subtitle)),
            children))) : (children);
    var Component = component || alert_1.default;
    return (core_1.jsx(Component, tslib_1.__assign({ className: "Alert", css: {
            backgroundColor: dark
                ? theme.colors.background.tint1
                : theme.colors.background.default,
            overflow: "hidden",
            position: "relative",
            boxShadow: theme.shadows[elevation],
            borderRadius: theme.radii.md
        } }, other),
        core_1.jsx("div", null,
            core_1.jsx("div", { className: "Alert__bar", css: {
                    width: theme.radii.md,
                    position: "absolute",
                    top: 0,
                    left: 0,
                    bottom: 0,
                    backgroundColor: accent
                } }),
            core_1.jsx("div", { className: "Alert__content", css: {
                    display: "flex",
                    alignItems: "flex-start",
                    padding: theme.spaces.md + " " + theme.spaces.md,
                    paddingRight: onRequestClose ? "3.5rem" : undefined
                } },
                contents,
                onRequestClose && (core_1.jsx(IconButton_1.CloseButton, { css: {
                        marginTop: "-0.45rem",
                        right: theme.spaces.sm,
                        position: "absolute"
                    }, onClick: onRequestClose }))))));
};
exports.Alert.displayName = "Alert";
exports.Alert.propTypes = {
    onRequestClose: prop_types_1.default.func,
    subtitle: prop_types_1.default.string,
    title: prop_types_1.default.string,
    id: prop_types_1.default.oneOfType([prop_types_1.default.string, prop_types_1.default.number]),
    children: prop_types_1.default.node,
    intent: prop_types_1.default.oneOf([
        "info",
        "success",
        "warning",
        "danger",
        "question"
    ]),
    elevation: prop_types_1.default.oneOf(["xs", "sm", "md", "lg", "xl"]),
    component: prop_types_1.default.elementType
};
