"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/** @jsx jsx */
var core_1 = require("@emotion/core");
var React = tslib_1.__importStar(require("react"));
var react_spring_1 = require("react-spring");
var prop_types_1 = tslib_1.__importDefault(require("prop-types"));
var use_measure_1 = require("./Hooks/use-measure");
var use_uid_1 = require("./Hooks/use-uid");
function useCollapse(defaultShow) {
    if (defaultShow === void 0) { defaultShow = false; }
    var _a = React.useState(defaultShow), show = _a[0], setShow = _a[1];
    var id = use_uid_1.useUid();
    function onClick() {
        setShow(!show);
    }
    return {
        show: show,
        id: id,
        buttonProps: {
            onClick: onClick,
            "aria-controls": id,
            "aria-expanded": show ? true : false
        },
        collapseProps: {
            id: id,
            show: show
        }
    };
}
exports.useCollapse = useCollapse;
/**
 * Hide and reveal content with an animation. Supports dynamic
 * heights.
 */
exports.Collapse = function (_a) {
    var children = _a.children, id = _a.id, show = _a.show, other = tslib_1.__rest(_a, ["children", "id", "show"]);
    var ref = React.useRef(null);
    var bounds = use_measure_1.useMeasure(ref).bounds;
    var prevShow = usePrevious(show);
    var height = react_spring_1.useSpring({
        from: { height: 0 },
        to: { height: show ? bounds.height : 0 },
        immediate: prevShow !== null && prevShow === show
    }).height;
    return (core_1.jsx(react_spring_1.animated.div, tslib_1.__assign({ id: id, css: {
            overflow: "hidden",
            willChange: "height, opacity"
        }, style: { height: height } }, other),
        core_1.jsx("div", { ref: ref }, children)));
};
exports.Collapse.propTypes = {
    children: prop_types_1.default.node,
    id: prop_types_1.default.string.isRequired,
    show: prop_types_1.default.bool.isRequired
};
function usePrevious(value) {
    var ref = React.useRef(null);
    React.useEffect(function () {
        ref.current = value;
    }, [value]);
    return ref.current;
}
exports.usePrevious = usePrevious;
