"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/** @jsx jsx */
var core_1 = require("@emotion/core");
var React = tslib_1.__importStar(require("react"));
var Text_1 = require("./Text");
var IconButton_1 = require("./IconButton");
var react_spring_1 = require("react-spring");
var Overlay_1 = require("./Overlay");
var focus_1 = require("./Hooks/focus");
var prop_types_1 = tslib_1.__importDefault(require("prop-types"));
var use_scroll_lock_1 = tslib_1.__importDefault(require("use-scroll-lock"));
var Providers_1 = require("./Theme/Providers");
/**
 * A dialog is useful for displaying infomation that
 * commands the user's attention.
 */
exports.Dialog = function (_a) {
    var isOpen = _a.isOpen, onRequestClose = _a.onRequestClose, mobileFullscreen = _a.mobileFullscreen, title = _a.title, children = _a.children, other = tslib_1.__rest(_a, ["isOpen", "onRequestClose", "mobileFullscreen", "title", "children"]);
    var theme = Providers_1.useTheme();
    var transitions = react_spring_1.useTransition(isOpen, null, {
        from: { opacity: 0, transform: "scale(0.9)" },
        enter: { opacity: 1, transform: "scale(1)" },
        leave: { opacity: 0, transform: "scale(0.9)" },
        config: { mass: 1, tension: 185, friction: 26 }
    });
    var scrollableRef = React.useRef(null);
    var ref = React.useRef(null);
    focus_1.useFocusElement(ref, isOpen);
    use_scroll_lock_1.default(isOpen, scrollableRef);
    return (core_1.jsx(React.Fragment, null,
        core_1.jsx(Overlay_1.Overlay, { onRequestClose: onRequestClose, isOpen: isOpen },
            core_1.jsx(React.Fragment, null, transitions.map(function (_a) {
                var _b, _c;
                var item = _a.item, key = _a.key, animationProps = _a.props;
                return item && (core_1.jsx(react_spring_1.animated.div, tslib_1.__assign({ key: key, className: "Dialog", "aria-modal": "true", ref: ref, tabIndex: -1, onClick: function (e) {
                        e.stopPropagation();
                    }, style: {
                        opacity: animationProps.opacity,
                        transform: animationProps.transform
                    }, css: [
                        (_b = {
                                zIndex: theme.zIndices.modal,
                                background: theme.colors.background.default,
                                boxShadow: theme.shadows.md,
                                borderRadius: theme.radii.lg,
                                margin: "16px",
                                width: "calc(100% - 32px)",
                                outline: "none"
                            },
                            _b[theme.mediaQueries.sm] = {
                                maxWidth: "500px",
                                margin: "30px auto"
                            },
                            _b[theme.mediaQueries.lg] = {
                                maxWidth: "650px",
                                margin: "30px auto"
                            },
                            _b),
                        mobileFullscreen && (_c = {
                                maxWidth: "none",
                                margin: 0,
                                width: "100vw",
                                height: "100vh",
                                borderRadius: 0,
                                boxShadow: "none"
                            },
                            _c[theme.mediaQueries.sm] = {
                                maxWidth: "none",
                                margin: "0"
                            },
                            _c[theme.mediaQueries.md] = {
                                maxWidth: "500px",
                                margin: "30px auto",
                                height: "auto",
                                boxShadow: theme.shadows.md,
                                borderRadius: theme.radii.lg,
                                width: "calc(100% - 32px)"
                            },
                            _c)
                    ] }, other),
                    core_1.jsx(React.Fragment, null,
                        title && (core_1.jsx(exports.DialogHeader, { className: "Dialog__header", css: {
                                display: "flex",
                                justifyContent: "space-between",
                                alignItems: "center",
                                padding: theme.spaces.lg + " " + theme.spaces.lg + " 0 " + theme.spaces.lg
                            }, title: title, onRequestClose: onRequestClose })),
                        core_1.jsx("div", { ref: scrollableRef }, children))));
            })))));
};
exports.Dialog.propTypes = {
    isOpen: prop_types_1.default.bool.isRequired,
    onRequestClose: prop_types_1.default.func.isRequired,
    title: prop_types_1.default.string,
    mobileFullscreen: prop_types_1.default.bool,
    children: prop_types_1.default.node
};
exports.DialogHeader = function (_a) {
    var title = _a.title, onRequestClose = _a.onRequestClose, other = tslib_1.__rest(_a, ["title", "onRequestClose"]);
    return (core_1.jsx("div", tslib_1.__assign({}, other),
        core_1.jsx(Text_1.Text, { wrap: false, variant: "h4" }, title),
        onRequestClose && core_1.jsx(IconButton_1.CloseButton, { onClick: onRequestClose })));
};
exports.DialogHeader.propTypes = {
    title: prop_types_1.default.string.isRequired,
    onRequestClose: prop_types_1.default.func
};
