"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/** @jsx jsx */
var core_1 = require("@emotion/core");
var React = tslib_1.__importStar(require("react"));
var Text_1 = require("./Text");
var visually_hidden_1 = tslib_1.__importDefault(require("@reach/visually-hidden"));
var prop_types_1 = tslib_1.__importDefault(require("prop-types"));
var colors_1 = require("./Theme/colors");
var use_uid_1 = require("./Hooks/use-uid");
var Providers_1 = require("./Theme/Providers");
var Button_1 = require("./Button");
var Icons_1 = require("./Icons");
var getInputSizes = function (theme) { return ({
    sm: core_1.css({
        fontSize: theme.fontSizes[0],
        padding: "0.25rem 0.5rem"
    }),
    md: core_1.css({
        fontSize: theme.fontSizes[1],
        padding: "0.5rem 0.75rem"
    }),
    lg: core_1.css({
        fontSize: theme.fontSizes[2],
        padding: "0.65rem 1rem"
    })
}); };
var InputGroupContext = React.createContext({
    uid: undefined,
    error: undefined
});
exports.InputGroup = function (_a) {
    var id = _a.id, label = _a.label, children = _a.children, error = _a.error, helpText = _a.helpText, hideLabel = _a.hideLabel, other = tslib_1.__rest(_a, ["id", "label", "children", "error", "helpText", "hideLabel"]);
    var uid = use_uid_1.useUid(id);
    var theme = Providers_1.useTheme();
    var isDark = theme.colors.mode === "dark";
    var danger = isDark
        ? theme.colors.intent.danger.light
        : theme.colors.intent.danger.base;
    return (core_1.jsx("div", tslib_1.__assign({ className: "InputGroup", css: {
            marginTop: theme.spaces.md,
            ":first-child": {
                marginTop: 0
            }
        } }, other),
        core_1.jsx(exports.Label, { hide: hideLabel, htmlFor: uid }, label),
        core_1.jsx(InputGroupContext.Provider, { value: {
                uid: uid,
                error: error
            } }, children),
        error && typeof error === "string" ? (core_1.jsx("div", { className: "InputGroup__error", css: {
                alignItems: "center",
                marginTop: theme.spaces.sm,
                display: "flex"
            } },
            core_1.jsx(Icons_1.IconAlertCircle, { size: "sm", color: danger }),
            core_1.jsx(Text_1.Text, { css: {
                    display: "block",
                    marginLeft: theme.spaces.xs,
                    fontSize: theme.fontSizes[0],
                    color: danger
                } }, error))) : (error),
        helpText && (core_1.jsx(Text_1.Text, { className: "InputGroup__help", css: {
                display: "block",
                marginTop: theme.spaces.xs,
                color: theme.colors.text.muted,
                fontSize: theme.fontSizes[0]
            }, variant: "body" }, helpText))));
};
exports.InputGroup.propTypes = {
    label: prop_types_1.default.string.isRequired,
    hideLabel: prop_types_1.default.bool,
    helpText: prop_types_1.default.string,
    error: prop_types_1.default.oneOfType([prop_types_1.default.string, prop_types_1.default.node]),
    id: prop_types_1.default.string,
    children: prop_types_1.default.node
};
function shadowBorder(color, opacity) {
    return "0 0 0 2px transparent inset, 0 0 0 1px " + colors_1.alpha(color, opacity) + " inset";
}
function getBaseStyles(theme) {
    var dark = theme.colors.mode === "dark";
    var baseStyles = core_1.css({
        display: "block",
        width: "100%",
        lineHeight: theme.lineHeights.body,
        color: theme.colors.text.default,
        backgroundColor: "transparent",
        backgroundImage: "none",
        backgroundClip: "padding-box",
        WebkitFontSmoothing: "antialiased",
        WebkitTapHighlightColor: "transparent",
        WebkitAppearance: "none",
        boxSizing: "border-box",
        touchAction: "manipulation",
        fontFamily: theme.fonts.base,
        border: "none",
        boxShadow: dark
            ? shadowBorder(theme.colors.palette.gray.lightest, 0.14)
            : shadowBorder(theme.colors.palette.gray.dark, 0.2),
        borderRadius: theme.radii.sm,
        transition: "background 0.25s cubic-bezier(0.35,0,0.25,1), border-color 0.15s cubic-bezier(0.35,0,0.25,1), box-shadow 0.15s cubic-bezier(0.35,0,0.25,1)",
        "::placeholder": {
            color: colors_1.alpha(theme.colors.text.default, 0.45)
        },
        ":focus": {
            boxShadow: dark
                ? Button_1.focusShadow(colors_1.alpha(theme.colors.palette.blue.light, 0.5), colors_1.alpha(theme.colors.palette.gray.dark, 0.4), colors_1.alpha(theme.colors.palette.gray.light, 0.2))
                : Button_1.focusShadow(colors_1.alpha(theme.colors.palette.blue.dark, 0.1), colors_1.alpha(theme.colors.palette.gray.dark, 0.2), colors_1.alpha(theme.colors.palette.gray.dark, 0.05)),
            outline: "none"
        },
        ":disabled": {
            opacity: dark ? 0.4 : 0.8,
            background: theme.colors.background.tint1,
            cursor: "not-allowed",
            boxShadow: dark
                ? shadowBorder(theme.colors.palette.gray.lightest, 0.15)
                : shadowBorder(theme.colors.palette.gray.dark, 0.12)
        },
        ":active": {
            background: theme.colors.background.tint1
        }
    });
    return baseStyles;
}
function useActiveStyle() {
    var _a = React.useState(false), active = _a[0], setActive = _a[1];
    return {
        bind: {
            onTouchStart: function () { return setActive(true); },
            onTouchEnd: function () { return setActive(false); }
        },
        active: active
    };
}
function useSharedStyle() {
    var theme = Providers_1.useTheme();
    var errorStyles = {
        boxShadow: shadowBorder(theme.colors.intent.danger.base, 0.45)
    };
    var baseStyles = React.useMemo(function () { return getBaseStyles(theme); }, [theme]);
    var inputSizes = React.useMemo(function () { return getInputSizes(theme); }, [theme]);
    var activeBackground = core_1.css({ background: theme.colors.background.tint1 });
    return {
        baseStyles: baseStyles,
        inputSizes: inputSizes,
        activeBackground: activeBackground,
        errorStyles: errorStyles
    };
}
/**
 * Our basic Input element. Use this when building customized
 * forms. Otherwise, stick with InputGroup
 */
exports.InputBase = function (_a) {
    var autoComplete = _a.autoComplete, autoFocus = _a.autoFocus, _b = _a.inputSize, inputSize = _b === void 0 ? "md" : _b, other = tslib_1.__rest(_a, ["autoComplete", "autoFocus", "inputSize"]);
    var _c = React.useContext(InputGroupContext), uid = _c.uid, error = _c.error;
    var _d = useActiveStyle(), bind = _d.bind, active = _d.active;
    var _e = useSharedStyle(), baseStyles = _e.baseStyles, inputSizes = _e.inputSizes, activeBackground = _e.activeBackground, errorStyles = _e.errorStyles;
    var height = Button_1.getHeight(inputSize);
    return (core_1.jsx("input", tslib_1.__assign({ id: uid, className: "Input", autoComplete: autoComplete, autoFocus: autoFocus }, bind, { css: [
            baseStyles,
            inputSizes[inputSize],
            active && activeBackground,
            error && errorStyles,
            { height: height }
        ] }, other)));
};
exports.InputBase.propTypes = {
    inputSize: prop_types_1.default.oneOf(["sm", "md", "lg"]),
    autoComplete: prop_types_1.default.bool,
    autoFocus: prop_types_1.default.bool
};
exports.Input = exports.InputBase;
/**
 * Textarea version of InputBase
 */
exports.TextArea = function (_a) {
    var _b = _a.inputSize, inputSize = _b === void 0 ? "md" : _b, other = tslib_1.__rest(_a, ["inputSize"]);
    var _c = useActiveStyle(), bind = _c.bind, active = _c.active;
    var _d = useSharedStyle(), baseStyles = _d.baseStyles, inputSizes = _d.inputSizes, activeBackground = _d.activeBackground, errorStyles = _d.errorStyles;
    var _e = React.useContext(InputGroupContext), uid = _e.uid, error = _e.error;
    return (core_1.jsx("textarea", tslib_1.__assign({ className: "TextArea", id: uid }, bind, { css: [
            baseStyles,
            inputSizes[inputSize],
            {
                overflow: "auto",
                resize: "vertical"
            },
            active && activeBackground,
            error && errorStyles
        ] }, other)));
};
exports.TextArea.propTypes = {
    inputSize: prop_types_1.default.oneOf(["sm", "md", "lg"])
};
/**
 * A styled Label to go along with input elements
 */
exports.Label = function (_a) {
    var children = _a.children, hide = _a.hide, other = tslib_1.__rest(_a, ["children", "hide"]);
    var theme = Providers_1.useTheme();
    var child = (core_1.jsx("label", tslib_1.__assign({ className: "Label", css: {
            display: "inline-block",
            marginBottom: hide ? 0 : theme.spaces.sm
        } }, other),
        core_1.jsx(Text_1.Text, { className: "Label__text", variant: "subtitle" }, children)));
    return hide ? core_1.jsx(visually_hidden_1.default, null, child) : child;
};
exports.Label.propTypes = {
    hide: prop_types_1.default.bool,
    children: prop_types_1.default.node
};
/**
 * A styled select menu
 */
exports.Select = function (_a) {
    var multiple = _a.multiple, _b = _a.inputSize, inputSize = _b === void 0 ? "md" : _b, other = tslib_1.__rest(_a, ["multiple", "inputSize"]);
    var theme = Providers_1.useTheme();
    var inputSizes = getInputSizes(theme);
    var _c = React.useContext(InputGroupContext), uid = _c.uid, error = _c.error;
    var selectSize = {
        sm: inputSizes.sm,
        md: inputSizes.md,
        lg: inputSizes.lg
    };
    var dark = theme.colors.mode === "dark";
    var height = Button_1.getHeight(inputSize);
    return (core_1.jsx("div", { className: "Select", css: {
            position: "relative"
        } },
        core_1.jsx("select", tslib_1.__assign({ className: "Select__input", id: uid, css: [
                selectSize[inputSize],
                {
                    WebkitAppearance: "none",
                    display: "block",
                    width: "100%",
                    lineHeight: theme.lineHeights.body,
                    height: height,
                    color: theme.colors.text.default,
                    background: "transparent",
                    fontFamily: theme.fonts.base,
                    boxShadow: "0 0 0 2px transparent inset, 0 0 0 1px " + (dark
                        ? colors_1.alpha(theme.colors.palette.gray.lightest, 0.14)
                        : colors_1.alpha(theme.colors.palette.gray.dark, 0.2)) + " inset",
                    border: "none",
                    backgroundClip: "padding-box",
                    borderRadius: theme.radii.sm,
                    margin: 0,
                    ":disabled": {
                        ":disabled": {
                            opacity: dark ? 0.4 : 0.8,
                            background: theme.colors.background.tint1,
                            cursor: "not-allowed",
                            boxShadow: "0 0 0 2px transparent inset, 0 0 0 1px " + (dark
                                ? colors_1.alpha(theme.colors.palette.gray.lightest, 0.15)
                                : colors_1.alpha(theme.colors.palette.gray.dark, 0.12)) + " inset"
                        }
                    },
                    ":focus": {
                        borderColor: theme.colors.palette.blue.base,
                        boxShadow: dark
                            ? Button_1.focusShadow(colors_1.alpha(theme.colors.palette.blue.light, 0.5), colors_1.alpha(theme.colors.palette.gray.dark, 0.4), colors_1.alpha(theme.colors.palette.gray.light, 0.2))
                            : Button_1.focusShadow(colors_1.alpha(theme.colors.palette.blue.dark, 0.1), colors_1.alpha(theme.colors.palette.gray.dark, 0.2), colors_1.alpha(theme.colors.palette.gray.dark, 0.05)),
                        outline: 0
                    }
                },
                error && {
                    boxShadow: shadowBorder(theme.colors.intent.danger.base, 0.45)
                }
            ], multiple: multiple }, other)),
        !multiple && (core_1.jsx(Icons_1.IconChevronDown, { className: "Select__icon", color: theme.colors.text.muted, css: {
                position: "absolute",
                top: "50%",
                right: "0.75rem",
                transform: "translateY(-50%)",
                pointerEvents: "none"
            } }))));
};
exports.Select.propTypes = {
    inputSize: prop_types_1.default.oneOf(["sm", "md", "lg"]),
    multiple: prop_types_1.default.bool
};
exports.Check = function (_a) {
    var label = _a.label, id = _a.id, disabled = _a.disabled, other = tslib_1.__rest(_a, ["label", "id", "disabled"]);
    var uid = use_uid_1.useUid(id);
    var theme = Providers_1.useTheme();
    return (core_1.jsx("div", tslib_1.__assign({ className: "Check", css: { display: "flex", alignItems: "center" } }, other),
        core_1.jsx("input", tslib_1.__assign({ disabled: disabled, className: "Check__input", type: "checkbox", id: uid }, other)),
        core_1.jsx("label", { className: "Check__label", css: {
                opacity: disabled ? 0.6 : undefined,
                marginLeft: theme.spaces.xs
            }, htmlFor: uid },
            core_1.jsx(Text_1.Text, null, label))));
};
exports.Check.propTypes = {
    label: prop_types_1.default.string.isRequired,
    id: prop_types_1.default.string,
    disabled: prop_types_1.default.bool
};
