"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/** @jsx jsx */
var core_1 = require("@emotion/core");
var Text_1 = require("./Text");
var prop_types_1 = tslib_1.__importDefault(require("prop-types"));
var Menu_1 = require("./Menu");
var Providers_1 = require("./Theme/Providers");
var noop_1 = require("./misc/noop");
var touchable_hook_1 = require("touchable-hook");
var compose_bind_1 = require("./Hooks/compose-bind");
exports.List = function (_a) {
    var children = _a.children, other = tslib_1.__rest(_a, ["children"]);
    return core_1.jsx("nav", tslib_1.__assign({}, other), children);
};
exports.List.propTypes = {
    children: prop_types_1.default.node
};
exports.ListItem = function (_a) {
    var _b;
    var primary = _a.primary, secondary = _a.secondary, contentBefore = _a.contentBefore, _c = _a.interactive, interactive = _c === void 0 ? true : _c, children = _a.children, _d = _a.wrap, wrap = _d === void 0 ? true : _d, contentAfter = _a.contentAfter, _e = _a.onPress, onPress = _e === void 0 ? noop_1.noOp : _e, _f = _a.component, Component = _f === void 0 ? "div" : _f, other = tslib_1.__rest(_a, ["primary", "secondary", "contentBefore", "interactive", "children", "wrap", "contentAfter", "onPress", "component"]);
    var interactiveProps = interactive
        ? {
            role: "button",
            tabIndex: 0
        }
        : {};
    var isLink = other.to || other.href;
    var _g = touchable_hook_1.useTouchable({
        onPress: onPress,
        behavior: isLink ? "link" : "button"
    }), bind = _g.bind, hover = _g.hover, active = _g.active;
    var theme = Providers_1.useTheme();
    return (core_1.jsx(Component, tslib_1.__assign({ className: "ListItem", css: [
            (_b = {
                    display: "block",
                    textDecoration: "none",
                    outline: "none",
                    padding: theme.spaces.md,
                    background: "transparent",
                    WebkitTapHighlightColor: "transparent",
                    transition: "background 0.07s ease"
                },
                _b[theme.mediaQueries.md] = {
                    paddingLeft: theme.spaces.lg,
                    paddingRight: theme.spaces.lg
                },
                _b[":last-child"] = {
                    borderBottom: "none"
                },
                _b),
            interactive && {
                cursor: "pointer",
                ":focus": {
                    boxShadow: "inset 0 0 3px " + theme.colors.text.selected
                },
                ":focus:not([data-focus-visible-added])": {
                    boxShadow: "none"
                }
            },
            interactive &&
                hover && {
                background: theme.colors.background.tint1
            },
            interactive &&
                active && {
                background: theme.colors.background.tint2
            }
        ] }, interactiveProps, compose_bind_1.safeBind(bind, other)),
        core_1.jsx("div", { className: "ListItem__container", css: { display: "flex", alignItems: "center" } },
            contentBefore && (core_1.jsx("div", { className: "ListItem__content-before", css: { marginRight: theme.spaces.md } }, contentBefore)),
            core_1.jsx("div", { className: "ListItem__content", css: { flex: 1, overflow: "hidden" } },
                core_1.jsx(Text_1.Text, { className: "ListItem__primary", wrap: wrap, variant: "body", css: { display: "block", fontWeight: 500 } }, primary),
                secondary && (core_1.jsx(Text_1.Text, { className: "ListItem__secondary", wrap: wrap, css: { display: "block", fontSize: theme.fontSizes[0] }, variant: "body", muted: true }, secondary)),
                children),
            contentAfter && (core_1.jsx("div", { className: "ListItem__content-after", css: { flex: "0 0 auto", marginLeft: theme.spaces.md } }, contentAfter)))));
};
exports.ListItem.propTypes = {
    primary: prop_types_1.default.oneOfType([prop_types_1.default.string, prop_types_1.default.node]).isRequired,
    secondary: prop_types_1.default.oneOfType([prop_types_1.default.string, prop_types_1.default.node]),
    contentBefore: prop_types_1.default.node,
    contentAfter: prop_types_1.default.node,
    wrap: prop_types_1.default.bool,
    children: prop_types_1.default.node,
    interactive: prop_types_1.default.bool,
    onPress: prop_types_1.default.func,
    component: prop_types_1.default.elementType
};
exports.ListSection = function (_a) {
    var _b;
    var title = _a.title, children = _a.children, _c = _a.sticky, sticky = _c === void 0 ? true : _c, other = tslib_1.__rest(_a, ["title", "children", "sticky"]);
    var theme = Providers_1.useTheme();
    var bg = theme.colors.background.layer;
    return (core_1.jsx("div", { css: {
            ":first-child > *": {
                borderTop: "none"
            }
        } },
        core_1.jsx(Menu_1.MenuLabel, tslib_1.__assign({ css: (_b = {
                    position: sticky ? "sticky" : "static",
                    top: 0,
                    backgroundColor: sticky ? bg : "transparent",
                    padding: theme.spaces.sm,
                    paddingLeft: theme.spaces.md,
                    marginTop: theme.spaces.md
                },
                _b[theme.mediaQueries.md] = {
                    paddingLeft: theme.spaces.lg,
                    paddingRight: theme.spaces.lg
                },
                _b) }, other), title),
        children));
};
exports.ListSection.propTypes = {
    title: prop_types_1.default.string.isRequired,
    sticky: prop_types_1.default.bool,
    children: prop_types_1.default.node
};
