"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/** @jsx jsx */
var core_1 = require("@emotion/core");
var React = tslib_1.__importStar(require("react"));
var Text_1 = require("./Text");
var prop_types_1 = tslib_1.__importDefault(require("prop-types"));
var Sheet_1 = require("./Sheet");
var Providers_1 = require("./Theme/Providers");
var noop_1 = require("./misc/noop");
var touchable_hook_1 = require("touchable-hook");
var classnames_1 = tslib_1.__importDefault(require("classnames"));
var compose_bind_1 = require("./Hooks/compose-bind");
var KeyCodes = {
    ArrowUp: 38,
    ArrowDown: 40,
    Home: 36,
    End: 35
};
var MenuListContext = React.createContext({
    focus: false,
    onKeyDown: function () { }
});
exports.MenuList = function (_a) {
    var children = _a.children, _b = _a.focusableChildren, focusableChildren = _b === void 0 ? [] : _b, other = tslib_1.__rest(_a, ["children", "focusableChildren"]);
    var theme = Providers_1.useTheme();
    var disabled = new Map();
    var _c = React.useState(null), focusIndex = _c[0], setFocusIndex = _c[1];
    var kids = React.Children.toArray(children);
    var focusComponents = [exports.MenuItem].concat(focusableChildren);
    var focusableItems = kids.filter(function (kid) {
        return React.isValidElement(kid) &&
            focusComponents.indexOf(kid.type) > -1;
    });
    var lastIndex = focusableItems.length - 1;
    var firstIndex = 0;
    return (core_1.jsx("div", tslib_1.__assign({ role: "menu", onKeyDown: function (e) {
            if (e.keyCode === KeyCodes.ArrowDown ||
                (e.keyCode === KeyCodes.ArrowUp && focusIndex === null)) {
                e.preventDefault();
                setFocusIndex(0);
            }
        }, css: {
            minWidth: "200px",
            display: "block",
            padding: theme.spaces.sm + " 0"
        } }, other), kids.map(function (kid) {
        if (!React.isValidElement(kid)) {
            return null;
        }
        var i = focusableItems.indexOf(kid);
        if (i < 0) {
            return kid;
        }
        disabled.set(i, kid.props.disabled);
        function focusDown(current) {
            var next = current + 1 > lastIndex ? firstIndex : current + 1;
            if (disabled.get(next)) {
                focusDown(next);
            }
            else {
                setFocusIndex(next);
            }
        }
        function focusUp(current) {
            var next = current - 1 < firstIndex ? lastIndex : current - 1;
            if (disabled.get(next)) {
                focusUp(next);
            }
            else {
                setFocusIndex(next);
            }
        }
        var index = focusIndex || 0;
        return (core_1.jsx(MenuListContext.Provider, { key: i, value: {
                focus: i === focusIndex,
                onKeyDown: function (e) {
                    if (e.keyCode === KeyCodes.ArrowDown) {
                        e.preventDefault();
                        focusDown(index);
                    }
                    else if (e.keyCode === KeyCodes.ArrowUp) {
                        e.preventDefault();
                        focusUp(index);
                    }
                    else if (e.keyCode === KeyCodes.Home) {
                        e.preventDefault();
                        setFocusIndex(firstIndex);
                    }
                    else if (e.keyCode === KeyCodes.End) {
                        e.preventDefault();
                        setFocusIndex(lastIndex);
                    }
                }
            } }, kid));
    })));
};
exports.MenuList.propTypes = {
    children: prop_types_1.default.node,
    focusableChildren: prop_types_1.default.arrayOf(prop_types_1.default.elementType)
};
exports.MenuItem = function (_a) {
    var _b;
    var contentBefore = _a.contentBefore, contentAfter = _a.contentAfter, _c = _a.onPress, onPress = _c === void 0 ? noop_1.noOp : _c, _d = _a.className, className = _d === void 0 ? "" : _d, _e = _a.component, Component = _e === void 0 ? "div" : _e, _f = _a.role, role = _f === void 0 ? "menuitem" : _f, children = _a.children, disabled = _a.disabled, other = tslib_1.__rest(_a, ["contentBefore", "contentAfter", "onPress", "className", "component", "role", "children", "disabled"]);
    var theme = Providers_1.useTheme();
    var dark = theme.colors.mode === "dark";
    var localRef = React.useRef(null);
    var closeParent = React.useContext(Sheet_1.RequestCloseContext);
    var _g = React.useContext(MenuListContext), focus = _g.focus, onKeyDown = _g.onKeyDown;
    var isLink = Component === "a" || other.href || other.to;
    var _h = touchable_hook_1.useTouchable({
        onPress: select,
        disabled: disabled,
        delay: 0,
        behavior: isLink ? "link" : "button"
    }), bind = _h.bind, hover = _h.hover, active = _h.active;
    React.useEffect(function () {
        if (focus && localRef.current) {
            localRef.current.focus();
        }
    }, [focus, localRef]);
    function select() {
        onPress();
        closeParent();
    }
    return (core_1.jsx(Component, tslib_1.__assign({ className: classnames_1.default("MenuItem", "Touchable", className, {
            "Touchable--hover": hover,
            "Touchable--active": active
        }), css: [
            (_b = {
                    cursor: "pointer",
                    padding: "calc(" + theme.spaces.sm + " + 0.25rem) calc(" + theme.spaces.md + " + 0.25rem)"
                },
                _b[theme.mediaQueries.sm] = {
                    padding: theme.spaces.sm + " " + theme.spaces.md
                },
                _b.opacity = disabled ? 0.3 : 1,
                _b.display = "flex",
                _b.textDecoration = "none",
                _b.transition = "background-color 0.1s ease",
                _b.WebkitTapHighlightColor = "transparent",
                _b.color = theme.colors.text.default,
                _b.alignItems = "center",
                _b[":focus"] = {
                    outline: theme.outline
                },
                _b[":focus:not([data-focus-visible-added])"] = {
                    outline: "none"
                },
                _b[theme.mediaQueries.md] = {
                    padding: theme.spaces.xs + " " + theme.spaces.md
                },
                _b),
            hover && {
                background: dark
                    ? theme.colors.background.tint2
                    : theme.colors.background.tint1
            },
            active && {
                background: theme.colors.background.tint2
            }
        ], role: role, tabIndex: disabled ? -1 : 0, "data-trigger-close": true }, compose_bind_1.safeBind(bind, {
        ref: localRef,
        onKeyDown: function (e) {
            e.stopPropagation();
            if (onKeyDown)
                onKeyDown(e);
        }
    }, other)),
        contentBefore,
        typeof children === "string" ? (core_1.jsx(Text_1.Text, { wrap: false, css: {
                paddingLeft: contentBefore ? theme.spaces.md : 0,
                paddingRight: contentAfter ? theme.spaces.md : 0,
                flex: 1,
                color: "inherit"
            } }, children)) : (children),
        typeof contentAfter === "string" ? (core_1.jsx(Text_1.Text, { muted: true }, contentAfter)) : (contentAfter)));
};
exports.MenuItem.propTypes = {
    onSelect: prop_types_1.default.func,
    component: prop_types_1.default.string,
    disabled: prop_types_1.default.bool,
    children: prop_types_1.default.node,
    contentBefore: prop_types_1.default.node,
    contentAfter: prop_types_1.default.node,
    onPress: prop_types_1.default.func,
    className: prop_types_1.default.string,
    role: prop_types_1.default.string
};
function MenuDivider(props) {
    var theme = Providers_1.useTheme();
    return (core_1.jsx("div", tslib_1.__assign({ css: {
            height: 0,
            margin: theme.spaces.sm + " 0",
            overflow: "hidden",
            borderTop: "1px solid",
            borderColor: theme.colors.border.muted
        } }, props)));
}
exports.MenuDivider = MenuDivider;
exports.MenuLabel = function (props) {
    var theme = Providers_1.useTheme();
    return (core_1.jsx(Text_1.Text, tslib_1.__assign({ variant: "uppercase", css: {
            padding: theme.spaces.xs + " " + theme.spaces.md
        } }, props)));
};
exports.MenuLabel.propTypes = {
    children: prop_types_1.default.node
};
