"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/** @jsx jsx */
var core_1 = require("@emotion/core");
var React = tslib_1.__importStar(require("react"));
var Layer_1 = require("./Layer");
var Positions_1 = require("./Positions");
var Tooltip_1 = require("./Tooltip");
var focus_1 = require("./Hooks/focus");
var react_spring_1 = require("react-spring");
var Sheet_1 = require("./Sheet");
var use_media_1 = require("use-media");
var prop_types_1 = tslib_1.__importDefault(require("prop-types"));
var Providers_1 = require("./Theme/Providers");
var merge_refs_1 = require("./Hooks/merge-refs");
var AnimatedLayer = react_spring_1.animated(Layer_1.Layer);
exports.Popover = function (_a) {
    var content = _a.content, children = _a.children, placement = _a.placement, _b = _a.closeOnMenuItemClick, closeOnMenuItemClick = _b === void 0 ? true : _b, _c = _a.isOpen, defaultShow = _c === void 0 ? false : _c;
    var theme = Providers_1.useTheme();
    var _d = React.useState(defaultShow), show = _d[0], setShow = _d[1];
    var child = React.Children.only(children);
    var triggerRef = React.useRef(null);
    var popoverRef = React.useRef(null);
    focus_1.useFocusElement(popoverRef, show, {
        escapeDeactivates: true,
        clickOutsideDeactivates: true
    });
    var bg = theme.colors.mode === "dark"
        ? theme.colors.background.tint1
        : theme.colors.background.layer;
    function open() {
        setShow(true);
        document.body.addEventListener("click", onBodyClick, false);
        document.body.addEventListener("keydown", onBodyKeyDown, false);
    }
    var unmount = React.useCallback(removeBodyListeners, []);
    React.useEffect(function () { return unmount; }, [unmount]);
    function close() {
        setShow(false);
        removeBodyListeners();
    }
    function removeBodyListeners() {
        document.body.removeEventListener("click", onBodyClick, false);
        document.body.removeEventListener("keydown", onBodyKeyDown, false);
    }
    function onBodyClick(e) {
        var trigger = triggerRef.current;
        var popover = popoverRef.current;
        if (!trigger || !popover) {
            return;
        }
        // Don't close if clicking the trigger
        if (trigger === e.target || trigger.contains(e.target)) {
            return;
        }
        // or the popover, sometimes
        if (popover === e.target || popover.contains(e.target)) {
            if (closeOnMenuItemClick) {
                var target = e.target;
                if (target.hasAttribute('[data-trigger-close="true"]') ||
                    target.closest('[data-trigger-close="true"]')) {
                    close();
                    return;
                }
            }
            return;
        }
        close();
    }
    function onBodyKeyDown(e) {
        // close on escape key or enter
        if (e.keyCode === 27) {
            close();
        }
        // close on enter
        if (closeOnMenuItemClick && e.keyCode === 13) {
            close();
        }
    }
    function renderTrigger(_a) {
        var ref = _a.ref;
        return React.cloneElement(child, {
            onPress: function (e) {
                onTriggerClicked();
                if (child.props.onPress) {
                    child.props.onPress(e);
                }
            },
            ref: merge_refs_1.mergeRefs(ref, triggerRef),
            role: "button",
            "aria-expanded": show,
            "aria-haspopup": true
        });
    }
    function onTriggerClicked() {
        return show ? close() : open();
    }
    return (core_1.jsx(Positions_1.Positioner, { placement: placement, isOpen: show, target: renderTrigger }, function (_a, animation) {
        var placement = _a.placement, ref = _a.ref, arrowProps = _a.arrowProps, style = _a.style;
        return (core_1.jsx(AnimatedLayer, { role: "dialog", elevation: "md", ref: merge_refs_1.mergeRefs(ref, popoverRef), style: tslib_1.__assign({}, style, { opacity: animation.opacity }), "data-placement": placement, css: {
                zIndex: theme.zIndices.popover,
                margin: theme.spaces.sm,
                borderRadius: theme.radii.md,
                background: bg
            } },
            core_1.jsx("div", { "data-placement": placement, css: Tooltip_1.arrowStyles(bg), ref: arrowProps.ref, style: arrowProps.style }),
            content));
    }));
};
exports.Popover.propTypes = {
    isOpen: prop_types_1.default.bool,
    children: prop_types_1.default.node,
    content: prop_types_1.default.node,
    closeOnMenuItemClick: prop_types_1.default.bool,
    placement: prop_types_1.default.oneOf([
        "auto-start",
        "auto",
        "auto-end",
        "top-start",
        "top",
        "top-end",
        "right-start",
        "right",
        "right-end",
        "bottom-end",
        "bottom",
        "bottom-start",
        "left-end",
        "left",
        "left-start"
    ])
};
/**
 * Display popover contents in a bottom sheet if
 * on mobile devices. I generally find that this provides a
 * better use experience on smaller screens.
 */
exports.ResponsivePopover = function (props) {
    var theme = Providers_1.useTheme();
    // show popover on iPad+
    var showPopover = use_media_1.useMedia({
        minWidth: theme.breakpoints.sm
    });
    var _a = React.useState(false), isOpen = _a[0], setIsOpen = _a[1];
    if (showPopover) {
        return core_1.jsx(exports.Popover, tslib_1.__assign({}, props));
    }
    return (core_1.jsx(React.Fragment, null,
        React.cloneElement(React.Children.only(props.children), {
            onPress: function () {
                setIsOpen(true);
            }
        }),
        core_1.jsx(Sheet_1.Sheet, { position: "bottom", isOpen: isOpen, onRequestClose: function () {
                setIsOpen(false);
            } }, props.content)));
};
exports.ResponsivePopover.propTypes = tslib_1.__assign({}, exports.Popover.propTypes);
