"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/** @jsx jsx */
var core_1 = require("@emotion/core");
var React = tslib_1.__importStar(require("react"));
var react_gesture_responder_1 = require("react-gesture-responder");
var react_spring_1 = require("react-spring");
var prop_types_1 = tslib_1.__importDefault(require("prop-types"));
var compose_bind_1 = require("./Hooks/compose-bind");
/**
 * A scroll view with some helpers, including:
 *  - smooth scrolling
 *  - gesture claiming
 * @param param0
 * @param componentRef
 */
var ScrollViewForward = function (_a, componentRef) {
    var overflowY = _a.overflowY, children = _a.children, overflowX = _a.overflowX, innerRef = _a.innerRef, _b = _a.scrollAnimationConfig, scrollAnimationConfig = _b === void 0 ? { tension: 190, friction: 15, mass: 0.2 } : _b, other = tslib_1.__rest(_a, ["overflowY", "children", "overflowX", "innerRef", "scrollAnimationConfig"]);
    var ref = React.useRef(null);
    /**
     * A spring for animating scroll positions
     */
    var _c = react_spring_1.useSpring(function () {
        return {
            config: scrollAnimationConfig,
            from: { x: 0, y: 0 },
            to: { x: 0, y: 0 },
            onFrame: function (animated) {
                if (overflowX && ref.current) {
                    ref.current.scrollLeft = animated.x;
                }
                if (overflowY && ref.current) {
                    ref.current.scrollTop = animated.y;
                }
            }
        };
    }), setScroll = _c[1];
    /**
     * Expose an imperate scrollTo method
     */
    React.useImperativeHandle(componentRef, function () { return ({
        scrollTo: function (x, y) {
            if (ref.current) {
                var from = {
                    x: ref.current.scrollLeft,
                    y: ref.current.scrollTop
                };
                setScroll({
                    from: from,
                    to: { x: x, y: y },
                    reset: true
                });
            }
        }
    }); }, [setScroll]);
    /**
     * Use a pan responder to determine if our scrollview should
     * claim the responder (and cancel other gestures out). Only
     * enabled on touch devices.
     */
    var bind = react_gesture_responder_1.useGestureResponder({
        onStartShouldSet: function () { return false; },
        onTerminationRequest: function () { return false; },
        onMoveShouldSet: function (_a) {
            var initial = _a.initial, initialDirection = _a.initialDirection, xy = _a.xy;
            if (initialDirection[0] !== 0 && overflowX) {
                return true;
            }
            if (initialDirection[1] !== 0 && overflowY) {
                return true;
            }
            return false;
        }
    }, {
        enableMouse: false
    }).bind;
    return (core_1.jsx("div", tslib_1.__assign({ className: "ScrollView" }, other, bind),
        core_1.jsx("div", tslib_1.__assign({ className: "ScrollView__scroll-containerr", css: {
                transform: "translateZ(0)",
                overflowX: overflowX ? "scroll" : undefined,
                overflowY: overflowY ? "scroll" : undefined,
                WebkitOverflowScrolling: "touch"
            } }, compose_bind_1.safeBind({ ref: innerRef }, { ref: ref }, other)), children)));
};
ScrollViewForward.propTypes = {
    overflowY: prop_types_1.default.number,
    children: prop_types_1.default.node,
    overflowX: prop_types_1.default.number,
    scrollAnimationConfig: prop_types_1.default.shape({
        tension: prop_types_1.default.number,
        mass: prop_types_1.default.number,
        friction: prop_types_1.default.number
    })
};
exports.ScrollView = React.forwardRef(ScrollViewForward);
