"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/** @jsx jsx */
var core_1 = require("@emotion/core");
var React = tslib_1.__importStar(require("react"));
var Layer_1 = require("./Layer");
var prop_types_1 = tslib_1.__importDefault(require("prop-types"));
var Providers_1 = require("./Theme/Providers");
var TableSectionContext = React.createContext({
    type: "TableHead"
});
var TableContext = React.createContext({ fixed: false });
exports.Table = function (_a) {
    var children = _a.children, minWidth = _a.minWidth, fixed = _a.fixed, other = tslib_1.__rest(_a, ["children", "minWidth", "fixed"]);
    var theme = Providers_1.useTheme();
    return (core_1.jsx("div", { css: {
            width: "100%",
            display: "block",
            overflowX: minWidth ? "auto" : "initial"
        } },
        core_1.jsx("table", tslib_1.__assign({ css: {
                borderSpacing: 0,
                borderCollapse: "separate",
                width: "100%",
                fontFamily: theme.fonts.base,
                WebkitAppearance: "none",
                WebkitFontSmoothing: "antialiased",
                display: "table",
                minWidth: minWidth,
                tableLayout: fixed ? "fixed" : undefined
            } }, other),
            fixed && (core_1.jsx("colgroup", null, fixed.map(function (width, i) {
                return core_1.jsx("col", { key: i, width: width });
            }))),
            core_1.jsx(TableContext.Provider, { value: { fixed: fixed ? true : false } }, children))));
};
exports.Table.propTypes = {
    minWidth: prop_types_1.default.string,
    fixed: prop_types_1.default.arrayOf(prop_types_1.default.string),
    children: prop_types_1.default.node
};
function TableHead(_a) {
    var children = _a.children, other = tslib_1.__rest(_a, ["children"]);
    return (core_1.jsx("thead", tslib_1.__assign({ css: {
            display: "table-header-group"
        } }, other),
        core_1.jsx(TableSectionContext.Provider, { value: { type: "TableHead" } }, children)));
}
exports.TableHead = TableHead;
exports.TableRow = function (_a) {
    var onClick = _a.onClick, children = _a.children, other = tslib_1.__rest(_a, ["onClick", "children"]);
    var theme = Providers_1.useTheme();
    var tableSectionType = React.useContext(TableSectionContext).type;
    var buttonProps = onClick
        ? {
            role: "button",
            tabIndex: 0
        }
        : {};
    return (core_1.jsx("tr", tslib_1.__assign({ onClick: onClick, css: {
            height: tableSectionType === "TableHead" ? "31px" : "49px",
            display: "table-row",
            outline: "none",
            verticalAlign: "middle",
            cursor: onClick ? "pointer" : "default",
            ":hover": {
                background: onClick ? theme.colors.background.tint1 : "none"
            }
        } }, buttonProps, other), children));
};
exports.TableRow.propTypes = {
    onClick: prop_types_1.default.func,
    children: prop_types_1.default.node
};
/**
 * TableCell, used for both <td> and <th> elements.
 */
var tableCellAlignments = {
    right: core_1.css({
        textAlign: "right",
        flexDirection: "row-reverse"
    }),
    left: core_1.css({
        textAlign: "left"
    }),
    center: core_1.css({
        textAlign: "center"
    }),
    justify: core_1.css({
        textAlign: "justify"
    })
};
exports.TableCell = function (_a) {
    var _b;
    var _c = _a.align, align = _c === void 0 ? "left" : _c, variant = _a.variant, component = _a.component, ellipsis = _a.ellipsis, children = _a.children, other = tslib_1.__rest(_a, ["align", "variant", "component", "ellipsis", "children"]);
    var theme = Providers_1.useTheme();
    var tableSectionType = React.useContext(TableSectionContext).type;
    var Component = component || (tableSectionType === "TableHead" ? "th" : "td");
    var type = variant || (tableSectionType === "TableHead" ? "head" : "body");
    return (core_1.jsx(Component, tslib_1.__assign({ css: [
            (_b = {
                    zIndex: 4,
                    position: "relative",
                    borderBottom: "1px solid",
                    borderColor: tableSectionType === "TableBody"
                        ? theme.colors.border.muted
                        : theme.colors.border.default,
                    display: "table-cell",
                    padding: theme.spaces.xs + " " + theme.spaces.sm
                },
                _b[theme.mediaQueries.md] = {
                    paddingLeft: theme.spaces.md,
                    paddingRight: theme.spaces.md
                },
                _b[":last-child"] = {
                    paddingRight: theme.spaces.md
                },
                _b),
            ellipsis && {
                whiteSpace: "nowrap",
                textOverflow: "ellipsis",
                overflow: "hidden"
            },
            type === "head"
                ? {
                    fontWeight: 500,
                    fontSize: theme.fontSizes[0],
                    color: theme.colors.text.muted
                }
                : {
                    fontWeight: 400,
                    fontSize: theme.fontSizes[0],
                    color: theme.colors.text.default
                },
            tableCellAlignments[align]
        ], scope: "col" }, other), children));
};
exports.TableCell.propTypes = {
    align: prop_types_1.default.oneOf(Object.keys(tableCellAlignments)),
    variant: prop_types_1.default.oneOf(["body", "head"]),
    component: prop_types_1.default.elementType,
    ellipsis: prop_types_1.default.bool,
    children: prop_types_1.default.node
};
function TableBody(_a) {
    var children = _a.children, other = tslib_1.__rest(_a, ["children"]);
    return (core_1.jsx("tbody", tslib_1.__assign({ css: {
            display: "table-row-group"
        } }, other),
        core_1.jsx(TableSectionContext.Provider, { value: { type: "TableBody" } }, children)));
}
exports.TableBody = TableBody;
exports.ExpandingRow = function (_a) {
    var content = _a.content, children = _a.children;
    var theme = Providers_1.useTheme();
    var _b = React.useState(false), selected = _b[0], setSelected = _b[1];
    function close() {
        setSelected(false);
    }
    function open() {
        setSelected(true);
    }
    return (core_1.jsx(TableBody, null,
        core_1.jsx(exports.TableRow, { onClick: open }, children),
        selected && (core_1.jsx("tr", { css: { display: "table-row", height: "100px" } },
            core_1.jsx("td", { colSpan: React.Children.count(children), css: {
                    borderBottom: 0,
                    width: "inherit",
                    padding: 0,
                    position: "relative"
                } },
                core_1.jsx("div", { css: {
                        zIndex: 3,
                        width: "inherit",
                        position: "relative",
                        paddingBottom: "24px"
                    } },
                    core_1.jsx("div", { css: {
                            position: "relative",
                            whiteSpace: "normal",
                            height: "auto",
                            display: "block",
                            paddingTop: "24px"
                        } }, typeof content === "function" ? content(close) : content)),
                core_1.jsx(Layer_1.Layer, { css: {
                        position: "absolute",
                        top: "-49px",
                        left: "-16px",
                        right: "-16px",
                        borderRadius: theme.radii.md,
                        bottom: 0,
                        zIndex: 2
                    } }, null))))));
};
exports.ExpandingRow.propTypes = {
    content: prop_types_1.default.oneOfType([prop_types_1.default.func, prop_types_1.default.node]),
    children: prop_types_1.default.node
};
