"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
/** @jsx jsx */
var core_1 = require("@emotion/core");
var React = tslib_1.__importStar(require("react"));
var Text_1 = require("./Text");
var Button_1 = require("./Button");
var visually_hidden_1 = tslib_1.__importDefault(require("@reach/visually-hidden"));
var prop_types_1 = tslib_1.__importDefault(require("prop-types"));
var colors_1 = require("./Theme/colors");
var react_spring_1 = require("react-spring");
var previous_1 = require("./Hooks/previous");
var Badge_1 = require("./Badge");
var Providers_1 = require("./Theme/Providers");
var IconWrapper_1 = require("./IconWrapper");
var compute_scroll_into_view_1 = tslib_1.__importDefault(require("compute-scroll-into-view"));
var noop_1 = require("./misc/noop");
var use_measure_1 = require("./Hooks/use-measure");
var merge_refs_1 = require("./Hooks/merge-refs");
var Touchable_1 = require("./Touchable");
var classnames_1 = tslib_1.__importDefault(require("classnames"));
var ScrollView_1 = require("./ScrollView");
var hideScrollbar = core_1.css(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["\n  ::-webkit-scrollbar {\n    height: 0;\n    width: 0;\n  }\n"], ["\n  ::-webkit-scrollbar {\n    height: 0;\n    width: 0;\n  }\n"])));
/**
 * Provide a tabbed interface, similar to that found in Material-UI.
 */
exports.Tabs = function (_a) {
    var children = _a.children, _b = _a.variant, variant = _b === void 0 ? "default" : _b, _c = _a.slider, enableSlider = _c === void 0 ? true : _c, value = _a.value, _d = _a.animationConfig, animationConfig = _d === void 0 ? { tension: 190, friction: 15, mass: 0.2 } : _d, onChange = _a.onChange, other = tslib_1.__rest(_a, ["children", "variant", "slider", "value", "animationConfig", "onChange"]);
    var theme = Providers_1.useTheme();
    var boundary = React.useRef(null);
    var tablist = React.useRef(null);
    var refs = React.useRef(new Map());
    var dark = theme.colors.mode === "dark";
    // We store the 'value' prop to determine when we should actually
    // animated our slider. ie., only when the index changes.
    var _e = React.useState({
        right: 0,
        left: 0,
        value: value
    }), slider = _e[0], setSlider = _e[1];
    var _f = React.useState(false), showSlider = _f[0], setShowSlider = _f[1];
    var previousSlider = previous_1.usePrevious(slider);
    var scrollRef = React.useRef(null);
    var bounds = use_measure_1.useMeasure(boundary).bounds;
    // determine if we should scroll into view when our
    // value changes
    React.useEffect(function () {
        var target = refs.current.get(value);
        if (target) {
            var actions = compute_scroll_into_view_1.default(target, {
                block: "center",
                inline: "center",
                boundary: boundary.current
            });
            if (!actions.length) {
                return;
            }
            var left = actions[0].left;
            scrollRef.current.scrollTo(left);
        }
    }, [value]);
    // measure our elements
    React.useEffect(function () {
        var target = refs.current.get(value);
        var container = tablist.current;
        if (target) {
            var cRect = container.getBoundingClientRect();
            // when container is `display: none`, width === 0.
            // ignore this case
            if (cRect.width === 0) {
                return;
            }
            var tRect = target.getBoundingClientRect();
            var left = tRect.left - cRect.left;
            var right = cRect.right - tRect.right;
            setSlider({
                value: value,
                left: left + 8,
                right: right + 8
            });
            setShowSlider(true);
        }
    }, [value, bounds]);
    var spring = react_spring_1.useSpring({
        left: slider.left + "px",
        right: slider.right + "px",
        immediate: previousSlider ? previousSlider.value === slider.value : false,
        config: animationConfig // default friction is 160: speed up our animation slightly
    });
    // Thanks to Ryan Florence for this code
    // https://github.com/reach/reach-ui/blob/master/packages/tabs/src/index.js
    function onKeyDown(e) {
        var enabledIndexes = React.Children.map(children, function (child, index) {
            return child.props.disabled === true ? null : index;
        }).filter(function (index) { return index != null; });
        var enabledSelectedIndex = enabledIndexes.indexOf(value);
        switch (e.key) {
            case "ArrowRight": {
                var nextEnabledIndex = (enabledSelectedIndex + 1) % enabledIndexes.length;
                var nextIndex = enabledIndexes[nextEnabledIndex];
                if (typeof nextIndex === "number") {
                    onChange(nextIndex);
                }
                break;
            }
            case "ArrowLeft": {
                var count = enabledIndexes.length;
                var nextEnabledIndex = (enabledSelectedIndex - 1 + count) % count;
                var nextIndex = enabledIndexes[nextEnabledIndex];
                if (typeof nextIndex === "number") {
                    onChange(nextIndex);
                }
                break;
            }
            // todo: ArrowDown should focus our selected tab content
            case "Home": {
                onChange(0);
                break;
            }
            case "End": {
                onChange(React.Children.count(children) - 1);
                break;
            }
        }
    }
    return (core_1.jsx("div", tslib_1.__assign({ className: "Tabs", ref: boundary, css: {
            overflowY: "hidden",
            boxShadow: dark ? "0px 3px 2px rgba(0,0,0,0.15)" : "none"
        } }, other),
        core_1.jsx(ScrollView_1.ScrollView, { overflowX: true, className: "Tabs__container", ref: scrollRef, css: [
                {
                    width: "100%",
                    whiteSpace: "nowrap",
                    paddingBottom: "20px",
                    marginBottom: "-20px"
                },
                hideScrollbar
            ] },
            core_1.jsx("div", { className: "Tabs__tablist", role: "tablist", ref: tablist, onKeyDown: onKeyDown, css: {
                    display: variant === "evenly-spaced" ? "flex" : "inline-block",
                    position: "relative",
                    verticalAlign: "bottom",
                    "& button": {
                        flex: variant === "evenly-spaced" ? "1" : undefined
                    }
                } },
                React.Children.map(children, function (child, i) {
                    return React.cloneElement(child, {
                        isActive: i === value,
                        ref: function (el) {
                            refs.current.set(i, el);
                        },
                        onParentSelect: function () {
                            onChange(i);
                        }
                    });
                }),
                enableSlider && showSlider && (core_1.jsx(react_spring_1.animated.div, { className: "Tabs__slider", style: spring, css: {
                        height: "4px",
                        borderTopRightRadius: "8px",
                        borderTopLeftRadius: "8px",
                        marginLeft: theme.spaces.sm,
                        marginRight: theme.spaces.sm,
                        bottom: 0,
                        position: "absolute",
                        background: dark ? "white" : theme.colors.text.selected
                    } }))))));
};
exports.Tabs.propTypes = {
    value: prop_types_1.default.number.isRequired,
    onChange: prop_types_1.default.func,
    slider: prop_types_1.default.bool,
    variant: prop_types_1.default.oneOf(["default", "evenly-spaced"]),
    children: prop_types_1.default.node,
    animationConfig: prop_types_1.default.shape({
        tension: prop_types_1.default.number,
        friction: prop_types_1.default.number,
        mass: prop_types_1.default.number
    })
};
/**
 * A clickable tab item
 */
exports.Tab = React.forwardRef(function (_a, forwarded) {
    var _b;
    var onParentSelect = _a.onParentSelect, isActive = _a.isActive, id = _a.id, _c = _a.component, Component = _c === void 0 ? "button" : _c, badge = _a.badge, _d = _a.onPress, onPress = _d === void 0 ? noop_1.noOp : _d, children = _a.children, other = tslib_1.__rest(_a, ["onParentSelect", "isActive", "id", "component", "badge", "onPress", "children"]);
    var theme = Providers_1.useTheme();
    var dark = theme.colors.mode === "dark";
    /**
     * Determine text color
     */
    function getTextColor(isDark) {
        if (isDark) {
            return isActive ? "rgba(255,255,255,1)" : "rgba(255,255,255,0.65)";
        }
        return isActive ? theme.colors.text.selected : theme.colors.text.muted;
    }
    /**
     * Determine badge colors
     */
    function getBadgeColors(isDark) {
        var background = "white";
        var color = "white";
        if (isDark) {
            background = isActive ? "white" : "rgba(255,255,255,0.65)";
            color = isActive
                ? theme.colors.text.selected
                : theme.colors.text.selected;
        }
        else {
            background = isActive
                ? theme.colors.text.selected
                : theme.colors.scales.gray[6];
            color = isActive ? "white" : theme.colors.text.selected;
        }
        return {
            background: background,
            color: color
        };
    }
    var mounted = React.useRef(false);
    var ref = React.useRef(null);
    /**
     * Handle focus side-effects
     */
    React.useEffect(function () {
        // don't autofocus if mounting
        if (!mounted.current) {
            mounted.current = true;
            return;
        }
        if (!isActive) {
            return;
        }
        if (ref.current) {
            ref.current.focus();
        }
    }, [isActive]);
    var onPressFn = React.useCallback(function (e) {
        onPress(e);
        if (onParentSelect) {
            onParentSelect();
        }
    }, [onParentSelect, onPress]);
    return (core_1.jsx(Touchable_1.Touchable, tslib_1.__assign({ className: classnames_1.default("Tab", {
            "Tab--active": isActive
        }), component: Component, terminateOnScroll: false, onPress: onPressFn, delay: 0, css: [
            Button_1.buttonReset,
            (_b = {
                    padding: "10px " + theme.spaces.md
                },
                _b[theme.mediaQueries.lg] = {
                    padding: "10px " + theme.spaces.lg
                },
                _b.cursor = "pointer",
                _b.color = getTextColor(dark),
                _b.transition = "background 0.35s ease",
                _b.background = "transparent",
                _b["& span"] = {
                    transition: "color 0.25s cubic-bezier(0.35,0,0.25,1)"
                },
                _b["& svg"] = {
                    transition: "stroke 0.35s cubic-bezier(0.35,0,0.25,1)",
                    stroke: getTextColor(dark) + " !important"
                },
                _b[":focus"] = {
                    outline: "none",
                    background: dark
                        ? colors_1.alpha(theme.colors.background.tint2, 0.15)
                        : theme.colors.background.tint2
                },
                _b[":focus:not([data-focus-visible-added])"] = {
                    outline: "none",
                    background: "transparent"
                },
                _b["&.Touchable--active"] = {
                    color: dark
                        ? "rgba(255,255,255,0.4)"
                        : colors_1.alpha(theme.colors.text.selected, 0.4),
                    "& svg": {
                        stroke: (dark
                            ? "rgba(255,255,255,0.3)"
                            : colors_1.alpha(theme.colors.text.selected, 0.4)) + " !important"
                    }
                },
                _b)
        ], ref: merge_refs_1.mergeRefs(ref, forwarded), role: "tab", id: id + "-tab", "aria-controls": id, "aria-selected": isActive, tabIndex: isActive ? 0 : -1 }, other),
        typeof children === "string" ? (core_1.jsx(Text_1.Text, { wrap: false, component: "span", variant: "subtitle", css: {
                fontSize: theme.fontSizes[0],
                fontWeight: 600,
                color: "inherit",
                transition: "color 0.25s cubic-bezier(0.35,0,0.25,1)"
            } }, children)) : (children),
        badge && (core_1.jsx("div", { css: { display: "inline", marginLeft: theme.spaces.sm } }, typeof badge === "string" || typeof badge === "number" ? (core_1.jsx(Badge_1.Badge, { css: getBadgeColors(dark) }, badge)) : (badge)))));
});
exports.Tab.displayName = "Tab";
exports.Tab.propTypes = {
    id: prop_types_1.default.string.isRequired,
    children: prop_types_1.default.node,
    badge: prop_types_1.default.node
};
exports.TabPanel = function (_a) {
    var id = _a.id, other = tslib_1.__rest(_a, ["id"]);
    return (core_1.jsx("div", tslib_1.__assign({ id: id, role: "tabpanel", tabIndex: 0, "aria-labelledby": id + "-tab" }, other)));
};
exports.TabPanel.propTypes = {
    id: prop_types_1.default.string.isRequired
};
exports.TabIcon = function (_a) {
    var icon = _a.icon, label = _a.label, _b = _a.size, size = _b === void 0 ? "lg" : _b;
    return (core_1.jsx("div", { css: { display: "flex", justifyContent: "center" } },
        core_1.jsx(IconWrapper_1.IconWrapper, { size: size }, icon),
        core_1.jsx(visually_hidden_1.default, null, label)));
};
exports.TabIcon.propTypes = {
    icon: prop_types_1.default.node.isRequired,
    label: prop_types_1.default.string.isRequired,
    size: prop_types_1.default.number
};
var templateObject_1;
