"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var React = tslib_1.__importStar(require("react"));
var _1 = tslib_1.__importDefault(require("."));
/**
 * API:
 *
 * You can create custom themes using Object.assign:
 *
 *
 * Pass that theme to the theme provider. A theme should always
 * provide a dark and light color mode.
 *
 * <ThemeProvider theme={customTheme}><App /></ThemeProvider>
 *
 *
 * When you want to use a dark mode:
 *
 * function App () {
 *  return <Dark><SomeContent /></Dark>
 * }
 *
 *
 * To consume a theme, use `useTheme` hook
 *
 * const theme = useTheme()
 * // theme.colors.text.default (will be dark or light depending on the mode)
 * // theme.colors.mode === 'dark' or 'light'
 */
var ThemeContext = React.createContext(_1.default);
exports.ThemeProvider = function (_a) {
    var _b = _a.theme, theme = _b === void 0 ? _1.default : _b, children = _a.children;
    return (React.createElement(ThemeContext.Provider, { value: theme }, children));
};
/**
 * A hook for consuming the theme
 */
function useTheme() {
    return React.useContext(ThemeContext);
}
exports.useTheme = useTheme;
var ColorMode = React.forwardRef(function (_a, ref) {
    var colors = _a.colors, children = _a.children, other = tslib_1.__rest(_a, ["colors", "children"]);
    var theme = useTheme();
    // memo is necessary to prevent unnecessary rerenders
    // https://reactjs.org/docs/context.html#caveats
    var adjustedTheme = React.useMemo(function () { return mergeColors(theme, colors); }, [
        theme,
        colors
    ]);
    return (React.createElement(ThemeContext.Provider, { value: adjustedTheme }, typeof children === "function"
        ? children(adjustedTheme)
        : React.cloneElement(React.Children.only(children), tslib_1.__assign({ ref: ref }, other))));
});
ColorMode.displayName = "ColorMode";
function mergeColors(theme, colors) {
    return tslib_1.__assign({}, theme, { shadows: colors.shadows, colors: colors });
}
exports.LightMode = React.forwardRef(function (_a, ref) {
    var children = _a.children, other = tslib_1.__rest(_a, ["children"]);
    var theme = useTheme();
    return (React.createElement(ColorMode, tslib_1.__assign({ colors: theme.modes.light, ref: ref }, other), children));
});
exports.LightMode.displayName = "LightMode";
/**
 * Provide a dark theme
 */
exports.DarkMode = React.forwardRef(function (_a, ref) {
    var children = _a.children, other = tslib_1.__rest(_a, ["children"]);
    var theme = useTheme();
    return (React.createElement(ColorMode, tslib_1.__assign({ colors: theme.modes.dark, ref: ref }, other), children));
});
exports.DarkMode.displayName = "DarkMode";
