import * as React from "react";
import { LayerElevations } from "./Layer";
export declare type AlertIntentions = "info" | "success" | "question" | "danger" | "warning";
export interface AlertProps extends React.HTMLAttributes<HTMLDivElement> {
    /** If used, a close button will be attached to the alert box. */
    onRequestClose?: () => void;
    /** Primary text */
    title?: string;
    /** Secondary text */
    subtitle?: string | React.ReactNode;
    /** A unique id used for accessibility purposes */
    id?: string;
    elevation?: LayerElevations;
    /** Optionally render children if a title is not specified. Used for custom alerts. */
    children?: React.ReactNode;
    /** Changes the icon and colour of the alert. */
    intent?: AlertIntentions;
    component?: React.ReactType<any>;
    type?: "polite" | "assertive";
}
/**
 * Use an alert to inform users of important information.
 * To display an alert in a toast notification, use the toast module.
 */
export declare const Alert: React.FunctionComponent<AlertProps>;
