import * as tslib_1 from "tslib";
/** @jsx jsx */
import { jsx, css } from "@emotion/core";
import * as React from "react";
import { Text } from "./Text";
import PropTypes from "prop-types";
import { useTheme } from "./Theme/Providers";
import { IconChevronRight } from "./Icons";
var hideScrollbar = css(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["\n  ::-webkit-scrollbar {\n    height: 0;\n    width: 0;\n  }\n"], ["\n  ::-webkit-scrollbar {\n    height: 0;\n    width: 0;\n  }\n"])));
/**
 * Breadcrumbs are useful to orient the user on your site,
 * especially when working with hierarchies of content.
 */
export var Breadcrumbs = function (_a) {
    var children = _a.children, _b = _a.size, size = _b === void 0 ? "md" : _b, overflowX = _a.overflowX, other = tslib_1.__rest(_a, ["children", "size", "overflowX"]);
    var theme = useTheme();
    return (jsx("nav", tslib_1.__assign({ className: "Breadcrumbs", "aria-label": "breadcrumb", css: [
            {
                maxWidth: "100%",
                overflow: overflowX ? "scroll" : "hidden",
                WebkitOverflowScrolling: "touch",
                scrollbarWidth: "none",
                borderRadius: theme.radii.sm,
                msOverflowStyle: "none"
            },
            hideScrollbar
        ] }, other),
        jsx("ol", { className: "Breadcrumbs__list", css: {
                listStyle: "none",
                whiteSpace: "nowrap",
                display: "inline-flex",
                boxSizing: "border-box",
                overflow: "hidden",
                maxWidth: overflowX ? undefined : "100%",
                margin: 0,
                padding: theme.spaces.sm + " " + theme.spaces.md,
                borderRadius: theme.radii.md
            } }, React.Children.map(children, function (child, i) {
            if (!React.isValidElement(child)) {
                return child;
            }
            return React.cloneElement(child, {
                size: size,
                "aria-current": i === validChildrenCount(children) - 1 ? "page" : undefined
            });
        }))));
};
Breadcrumbs.propTypes = {
    children: PropTypes.node,
    size: PropTypes.oneOf(["md", "lg"]),
    overflowX: PropTypes.bool
};
function validChildrenCount(children) {
    return React.Children.toArray(children).filter(function (child) {
        return React.isValidElement(child);
    }).length;
}
/**
 *  Each item in a list of breadcrumbs.
 */
export var BreadcrumbItem = function (_a) {
    var children = _a.children, _b = _a.size, size = _b === void 0 ? "md" : _b, other = tslib_1.__rest(_a, ["children", "size"]);
    var current = other["aria-current"];
    return (jsx("li", tslib_1.__assign({ className: "BreadcrumbItem", css: {
            flex: "0 1 auto",
            overflow: "hidden",
            display: "flex",
            alignItems: "center"
        } }, other),
        jsx(Text, { className: "BreadcrumbItem__text", wrap: false, component: "div", variant: size === "md" ? "body" : "h5", gutter: false, css: {
                "& > a": {
                    textDecoration: "none"
                }
            } }, children),
        !current && jsx(BreadcrumbDivider, null)));
};
BreadcrumbItem.propTypes = {
    children: PropTypes.node,
    size: PropTypes.oneOf(["md", "lg"])
};
var BreadcrumbDivider = function () {
    var theme = useTheme();
    return (jsx(IconChevronRight, { className: "BreadcrumbDivider", color: theme.colors.text.muted, css: {
            flex: "0 0 auto",
            margin: "0 " + theme.spaces.sm
        } }));
};
BreadcrumbDivider.propTypes = {
    inverted: PropTypes.bool
};
var templateObject_1;
