import * as React from "react";
import { OnPressFunction } from "touchable-hook";
export declare type ButtonSize = "xs" | "sm" | "md" | "lg" | "xl";
export declare const getHeight: (size: "xs" | "sm" | "md" | "lg" | "xl") => "25px" | "30px" | "48px" | "60px" | "40px";
export declare function focusShadow(first: string, second: string, third: string): string;
export declare const buttonReset: import("@emotion/utils").SerializedStyles;
export declare type ButtonIntent = "none" | "warning" | "primary" | "success" | "danger";
declare const variants: {
    default: import("@emotion/utils").SerializedStyles;
    ghost: import("@emotion/utils").SerializedStyles;
    outline: import("@emotion/utils").SerializedStyles;
};
export declare type ButtonVariant = keyof typeof variants;
export interface ButtonStyleProps {
    /** Use onPress instead of onClick to handle both touch and click events */
    onPress?: OnPressFunction;
    /** Controls the basic button style. */
    variant?: ButtonVariant;
    /** Controls the colour of the button. */
    intent?: ButtonIntent;
    /** If true, the button will be displayed as a block element instead of inline. */
    block?: boolean;
    /** The size of the button. */
    size?: ButtonSize;
    /** Show a loading indicator */
    loading?: boolean;
    disabled?: boolean;
    /** The name of the icon to appear to the left of the button text*/
    iconBefore?: React.ReactNode;
    /** The name of the icon to appear to the right of the button text */
    iconAfter?: React.ReactNode;
    /** By default, a button element will only highlight after a short
     * delay to prevent unintended highlights when scrolling. You can set this to
     * 0 if the element is not in a scrollable container */
    pressDelay?: number;
    /**
     * By default, a touchable element will have an expanded press area of 20px
     * on touch devices. This will only effect touch devices.
     */
    pressExpandPx?: number;
}
export interface ButtonProps extends ButtonStyleProps, React.ButtonHTMLAttributes<HTMLButtonElement> {
    children: React.ReactNode;
    ref?: React.Ref<HTMLButtonElement>;
    component?: React.ReactType<any>;
    [key: string]: any;
}
/**
 * Your standard Button element
 */
export declare const Button: React.RefForwardingComponent<React.Ref<HTMLButtonElement>, ButtonProps>;
export {};
