import * as tslib_1 from "tslib";
/** @jsx jsx */
import { jsx } from "@emotion/core";
import * as React from "react";
import { animated, useSpring } from "react-spring";
import PropTypes from "prop-types";
import { useMeasure } from "./Hooks/use-measure";
import { useUid } from "./Hooks/use-uid";
export function useCollapse(defaultShow) {
    if (defaultShow === void 0) { defaultShow = false; }
    var _a = React.useState(defaultShow), show = _a[0], setShow = _a[1];
    var id = useUid();
    function onClick() {
        setShow(!show);
    }
    return {
        show: show,
        id: id,
        buttonProps: {
            onClick: onClick,
            "aria-controls": id,
            "aria-expanded": show ? true : false
        },
        collapseProps: {
            id: id,
            show: show
        }
    };
}
/**
 * Hide and reveal content with an animation. Supports dynamic
 * heights.
 */
export var Collapse = function (_a) {
    var children = _a.children, id = _a.id, show = _a.show, other = tslib_1.__rest(_a, ["children", "id", "show"]);
    var ref = React.useRef(null);
    var bounds = useMeasure(ref).bounds;
    var prevShow = usePrevious(show);
    var height = useSpring({
        from: { height: 0 },
        to: { height: show ? bounds.height : 0 },
        immediate: prevShow !== null && prevShow === show
    }).height;
    return (jsx(animated.div, tslib_1.__assign({ id: id, css: {
            overflow: "hidden",
            willChange: "height, opacity"
        }, style: { height: height } }, other),
        jsx("div", { ref: ref }, children)));
};
Collapse.propTypes = {
    children: PropTypes.node,
    id: PropTypes.string.isRequired,
    show: PropTypes.bool.isRequired
};
export function usePrevious(value) {
    var ref = React.useRef(null);
    React.useEffect(function () {
        ref.current = value;
    }, [value]);
    return ref.current;
}
