import * as React from "react";
export declare type InputSize = "sm" | "md" | "lg";
export interface InputGroupProps extends React.HTMLAttributes<HTMLDivElement> {
    id?: string;
    /** A label is required for accessibility purposes. Use `hideLabel` to hide it. */
    label: string;
    /** Visually hide the label. It remains accessible to screen readers. */
    hideLabel?: boolean;
    error?: string | React.ReactNode;
    /** Optional help text */
    helpText?: string;
    /** A single input element */
    children?: React.ReactNode;
}
export declare const InputGroup: React.FunctionComponent<InputGroupProps>;
export interface InputBaseProps extends React.InputHTMLAttributes<HTMLInputElement> {
    /** The size of the input element */
    inputSize?: InputSize;
}
/**
 * Our basic Input element. Use this when building customized
 * forms. Otherwise, stick with InputGroup
 */
export declare const InputBase: React.FunctionComponent<InputBaseProps>;
export declare const Input: React.FunctionComponent<InputBaseProps>;
export interface TextAreaProps extends React.TextareaHTMLAttributes<HTMLTextAreaElement> {
    /** The size of the textarea element */
    inputSize?: InputSize;
}
/**
 * Textarea version of InputBase
 */
export declare const TextArea: React.FunctionComponent<TextAreaProps>;
export interface LabelProps extends React.LabelHTMLAttributes<HTMLLabelElement> {
    hide?: boolean;
    htmlFor: string;
}
/**
 * A styled Label to go along with input elements
 */
export declare const Label: React.FunctionComponent<LabelProps>;
export interface SelectProps extends React.SelectHTMLAttributes<HTMLSelectElement> {
    /** The size of the select box */
    inputSize?: InputSize;
}
/**
 * A styled select menu
 */
export declare const Select: React.FunctionComponent<SelectProps>;
export interface CheckProps extends React.InputHTMLAttributes<HTMLInputElement> {
    /** A label for the checkmark. */
    label: string;
}
export declare const Check: React.FunctionComponent<CheckProps>;
