import * as React from "react";
import { SpringConfig } from "react-spring";
export declare const RequestCloseContext: React.Context<() => void>;
export declare type SheetPositions = "left" | "top" | "bottom" | "right";
interface SheetProps {
    /** Whether the sheet is visible */
    isOpen: boolean;
    /** A callback to handle closing the sheet */
    onRequestClose: () => void;
    role?: string;
    children: React.ReactNode;
    /**
     *  The position of the sheet.
     * 'left' is typically used for navigation,
     * 'right' for additional information,
     * 'bottom' for responsive modal popovers.
     */
    position: SheetPositions;
    /** spring animation configuration */
    animationConfig?: SpringConfig;
}
/**
 * A sheet is useful for displaying app based navigation (typically on the left),
 * supplemental information (on the right), or menu options (typically
 * from the bottom on mobile devices).
 *
 * Sheets should not be tied to specific URLs.
 */
export declare const Sheet: React.FunctionComponent<SheetProps>;
/**
 * Compare two positions and determine the direction
 * the gesture is moving (horizontal or vertical)
 *
 * If the difference is the same, return null. This happends
 * when only a click is registered.
 *
 * @param initial
 * @param xy
 */
export declare function getDirection(initial: [number, number], xy: [number, number]): "horizontal" | "vertical" | null;
export {};
