import * as tslib_1 from "tslib";
/** @jsx jsx */
import { jsx, css } from "@emotion/core";
import * as React from "react";
import { Layer } from "./Layer";
import PropTypes from "prop-types";
import { useTheme } from "./Theme/Providers";
var TableSectionContext = React.createContext({
    type: "TableHead"
});
var TableContext = React.createContext({ fixed: false });
export var Table = function (_a) {
    var children = _a.children, minWidth = _a.minWidth, fixed = _a.fixed, other = tslib_1.__rest(_a, ["children", "minWidth", "fixed"]);
    var theme = useTheme();
    return (jsx("div", { css: {
            width: "100%",
            display: "block",
            overflowX: minWidth ? "auto" : "initial"
        } },
        jsx("table", tslib_1.__assign({ css: {
                borderSpacing: 0,
                borderCollapse: "separate",
                width: "100%",
                fontFamily: theme.fonts.base,
                WebkitAppearance: "none",
                WebkitFontSmoothing: "antialiased",
                display: "table",
                minWidth: minWidth,
                tableLayout: fixed ? "fixed" : undefined
            } }, other),
            fixed && (jsx("colgroup", null, fixed.map(function (width, i) {
                return jsx("col", { key: i, width: width });
            }))),
            jsx(TableContext.Provider, { value: { fixed: fixed ? true : false } }, children))));
};
Table.propTypes = {
    minWidth: PropTypes.string,
    fixed: PropTypes.arrayOf(PropTypes.string),
    children: PropTypes.node
};
export function TableHead(_a) {
    var children = _a.children, other = tslib_1.__rest(_a, ["children"]);
    return (jsx("thead", tslib_1.__assign({ css: {
            display: "table-header-group"
        } }, other),
        jsx(TableSectionContext.Provider, { value: { type: "TableHead" } }, children)));
}
export var TableRow = function (_a) {
    var onClick = _a.onClick, children = _a.children, other = tslib_1.__rest(_a, ["onClick", "children"]);
    var theme = useTheme();
    var tableSectionType = React.useContext(TableSectionContext).type;
    var buttonProps = onClick
        ? {
            role: "button",
            tabIndex: 0
        }
        : {};
    return (jsx("tr", tslib_1.__assign({ onClick: onClick, css: {
            height: tableSectionType === "TableHead" ? "31px" : "49px",
            display: "table-row",
            outline: "none",
            verticalAlign: "middle",
            cursor: onClick ? "pointer" : "default",
            ":hover": {
                background: onClick ? theme.colors.background.tint1 : "none"
            }
        } }, buttonProps, other), children));
};
TableRow.propTypes = {
    onClick: PropTypes.func,
    children: PropTypes.node
};
/**
 * TableCell, used for both <td> and <th> elements.
 */
var tableCellAlignments = {
    right: css({
        textAlign: "right",
        flexDirection: "row-reverse"
    }),
    left: css({
        textAlign: "left"
    }),
    center: css({
        textAlign: "center"
    }),
    justify: css({
        textAlign: "justify"
    })
};
export var TableCell = function (_a) {
    var _b;
    var _c = _a.align, align = _c === void 0 ? "left" : _c, variant = _a.variant, component = _a.component, ellipsis = _a.ellipsis, children = _a.children, other = tslib_1.__rest(_a, ["align", "variant", "component", "ellipsis", "children"]);
    var theme = useTheme();
    var tableSectionType = React.useContext(TableSectionContext).type;
    var Component = component || (tableSectionType === "TableHead" ? "th" : "td");
    var type = variant || (tableSectionType === "TableHead" ? "head" : "body");
    return (jsx(Component, tslib_1.__assign({ css: [
            (_b = {
                    zIndex: 4,
                    position: "relative",
                    borderBottom: "1px solid",
                    borderColor: tableSectionType === "TableBody"
                        ? theme.colors.border.muted
                        : theme.colors.border.default,
                    display: "table-cell",
                    padding: theme.spaces.xs + " " + theme.spaces.sm
                },
                _b[theme.mediaQueries.md] = {
                    paddingLeft: theme.spaces.md,
                    paddingRight: theme.spaces.md
                },
                _b[":last-child"] = {
                    paddingRight: theme.spaces.md
                },
                _b),
            ellipsis && {
                whiteSpace: "nowrap",
                textOverflow: "ellipsis",
                overflow: "hidden"
            },
            type === "head"
                ? {
                    fontWeight: 500,
                    fontSize: theme.fontSizes[0],
                    color: theme.colors.text.muted
                }
                : {
                    fontWeight: 400,
                    fontSize: theme.fontSizes[0],
                    color: theme.colors.text.default
                },
            tableCellAlignments[align]
        ], scope: "col" }, other), children));
};
TableCell.propTypes = {
    align: PropTypes.oneOf(Object.keys(tableCellAlignments)),
    variant: PropTypes.oneOf(["body", "head"]),
    component: PropTypes.elementType,
    ellipsis: PropTypes.bool,
    children: PropTypes.node
};
export function TableBody(_a) {
    var children = _a.children, other = tslib_1.__rest(_a, ["children"]);
    return (jsx("tbody", tslib_1.__assign({ css: {
            display: "table-row-group"
        } }, other),
        jsx(TableSectionContext.Provider, { value: { type: "TableBody" } }, children)));
}
export var ExpandingRow = function (_a) {
    var content = _a.content, children = _a.children;
    var theme = useTheme();
    var _b = React.useState(false), selected = _b[0], setSelected = _b[1];
    function close() {
        setSelected(false);
    }
    function open() {
        setSelected(true);
    }
    return (jsx(TableBody, null,
        jsx(TableRow, { onClick: open }, children),
        selected && (jsx("tr", { css: { display: "table-row", height: "100px" } },
            jsx("td", { colSpan: React.Children.count(children), css: {
                    borderBottom: 0,
                    width: "inherit",
                    padding: 0,
                    position: "relative"
                } },
                jsx("div", { css: {
                        zIndex: 3,
                        width: "inherit",
                        position: "relative",
                        paddingBottom: "24px"
                    } },
                    jsx("div", { css: {
                            position: "relative",
                            whiteSpace: "normal",
                            height: "auto",
                            display: "block",
                            paddingTop: "24px"
                        } }, typeof content === "function" ? content(close) : content)),
                jsx(Layer, { css: {
                        position: "absolute",
                        top: "-49px",
                        left: "-16px",
                        right: "-16px",
                        borderRadius: theme.radii.md,
                        bottom: 0,
                        zIndex: 2
                    } }, null))))));
};
ExpandingRow.propTypes = {
    content: PropTypes.oneOfType([PropTypes.func, PropTypes.node]),
    children: PropTypes.node
};
