import * as React from "react";
import { SpringConfig } from "react-spring";
import { IconSizes } from "./Icons/IconTypes";
import { OnPressFunction } from "touchable-hook";
export interface TabsProps {
    /** The currently selected index */
    value: number;
    /** Toggle slider visibiliby */
    slider?: boolean;
    /** Whether tabs should be left-aligned or justified */
    variant?: "default" | "evenly-spaced";
    /** Change callback to control which tab is selected */
    onChange: (value: number) => void;
    /** Tab elements */
    children: React.ReactElement<TabProps>[] | React.ReactElement<TabProps>;
    /** spring animation configuration */
    animationConfig?: SpringConfig;
}
/**
 * Provide a tabbed interface, similar to that found in Material-UI.
 */
export declare const Tabs: React.FunctionComponent<TabsProps>;
/**
 * Tab
 */
interface LocalTabProps {
    ref: React.Ref<HTMLButtonElement>;
    onParentSelect: () => void;
    isActive: boolean;
}
export interface TabProps extends Partial<LocalTabProps>, React.HTMLAttributes<HTMLButtonElement> {
    /** The text content of the tab */
    children: React.ReactNode;
    onPress?: OnPressFunction;
    /** The id of the tab to be shared with TabContent */
    id: string;
    component?: React.ReactType<any>;
    [key: string]: any;
    /** An optional badge */
    badge?: React.ReactNode | string | number;
}
/**
 * A clickable tab item
 */
export declare const Tab: React.RefForwardingComponent<React.Ref<HTMLButtonElement>, TabProps>;
/**
 * A TabPanel should be used to wrap tab contents, unless those tabs
 * are anchors.
 */
export interface TabPanelProps extends React.HTMLAttributes<HTMLDivElement> {
    /** The id should correspond to the id given to the associated Tab */
    id: string;
}
export declare const TabPanel: React.FunctionComponent<TabPanelProps>;
export interface TabIconProps {
    icon: React.ReactNode;
    label: string;
    size?: IconSizes;
}
export declare const TabIcon: React.FunctionComponent<TabIconProps>;
export {};
