import * as React from "react";
export declare const getVariantStyles: (theme: {
    spaces: {
        none: number;
        xs: string;
        sm: string;
        md: string;
        lg: string;
        xl: string;
    };
    zIndices: {
        sticky: number;
        fixed: number;
        overlay: number;
        modal: number;
        popover: number;
        tooltip: number;
    };
    breakpoints: {
        sm: string;
        md: string;
        lg: string;
        xl: string;
    };
    mediaQueries: {
        sm: string;
        md: string;
        lg: string;
        xl: string;
        hover: string;
    };
    fontSizes: {
        0: string;
        1: string;
        2: string;
        3: string;
        4: string;
        5: string;
        6: string;
        7: string;
        8: string;
        9: string;
    };
    radii: {
        sm: string;
        md: string;
        lg: string;
    };
    fonts: {
        sans: string;
        base: string;
        monospace: string;
    };
    shadows: {
        xs: string;
        sm: string;
        md: string;
        lg: string;
        xl: string;
    };
    lineHeights: {
        heading: number;
        body: number;
    };
    fontWeights: {
        body: number;
        heading: number;
        display: number;
    };
    iconSizes: {
        xs: string;
        sm: string;
        md: string;
        lg: string;
        xl: string;
    };
    outline: string;
    colors: {
        palette: import("./Theme/colors").PaletteType;
        scales: {
            gray: string[];
            blue: string[];
            green: string[];
            red: string[];
            orange: string[];
            yellow: string[];
            teal: string[];
            cyan: string[];
            lime: string[];
            pink: string[];
            violet: string[];
            indigo: string[];
        };
        intent: {
            none: {
                lightest: string;
                light: string;
                base: string;
                dark: string;
            };
            primary: {
                lightest: string;
                light: string;
                base: string;
                dark: string;
            };
            success: {
                lightest: string;
                light: string;
                base: string;
                dark: string;
            };
            danger: {
                lightest: string;
                light: string;
                base: string;
                dark: string;
            };
            warning: {
                lightest: string;
                light: string;
                base: string;
                dark: string;
            };
        };
        background: {
            tint1: string;
            tint2: string;
            overlay: string;
            layer: string;
            default: string;
        };
        border: {
            default: string;
            muted: string;
        };
        text: {
            heading: string;
            muted: string;
            default: string;
            selected: string;
        };
        shadows: {
            xs: string;
            sm: string;
            md: string;
            lg: string;
            xl: string;
        };
        mode: string;
    };
    modes: {
        light: {
            palette: import("./Theme/colors").PaletteType;
            scales: {
                gray: string[];
                blue: string[];
                green: string[];
                red: string[];
                orange: string[];
                yellow: string[];
                teal: string[];
                cyan: string[];
                lime: string[];
                pink: string[];
                violet: string[];
                indigo: string[];
            };
            intent: {
                none: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
                primary: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
                success: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
                danger: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
                warning: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
            };
            background: {
                tint1: string;
                tint2: string;
                overlay: string;
                layer: string;
                default: string;
            };
            border: {
                default: string;
                muted: string;
            };
            text: {
                heading: string;
                muted: string;
                default: string;
                selected: string;
            };
            shadows: {
                xs: string;
                sm: string;
                md: string;
                lg: string;
                xl: string;
            };
            mode: string;
        };
        dark: {
            palette: import("./Theme/colors").PaletteType;
            scales: {
                gray: string[];
                blue: string[];
                green: string[];
                red: string[];
                orange: string[];
                yellow: string[];
                teal: string[];
                cyan: string[];
                lime: string[];
                pink: string[];
                violet: string[];
                indigo: string[];
            };
            intent: {
                none: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
                primary: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
                success: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
                danger: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
                warning: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
            };
            background: {
                tint1: string;
                tint2: string;
                overlay: string;
                layer: string;
                default: string;
            };
            border: {
                default: string;
                muted: string;
            };
            text: {
                heading: string;
                muted: string;
                default: string;
                selected: string;
            };
            shadows: {
                xs: string;
                sm: string;
                md: string;
                lg: string;
                xl: string;
            };
            mode: string;
        };
    };
}, variant: TextVariants) => import("@emotion/utils").SerializedStyles | undefined;
export declare type TextVariants = "uppercase" | "hidden" | "body" | "paragraph" | "subtitle" | "lead" | "h6" | "h5" | "h4" | "h3" | "h2" | "h1" | "display3" | "display2" | "display1";
export interface TextProps extends React.HTMLAttributes<HTMLElement> {
    /** The text style */
    variant?: TextVariants;
    /** Use text-overflow: ellipsis styling when set to false */
    wrap?: boolean;
    /** Use muted colors */
    muted?: boolean;
    /** Set to false to remove any bottom margins */
    gutter?: boolean;
    component?: React.ReactType<TextProps>;
}
export declare const Text: React.FunctionComponent<TextProps>;
