import * as React from "react";
import { Theme, ThemeColors } from ".";
/**
 * Provide a theme to your app using React Context
 */
export interface ThemeProviderProps {
    children: React.ReactNode;
    theme?: Theme;
}
export declare const ThemeProvider: ({ theme, children }: ThemeProviderProps) => JSX.Element;
/**
 * A hook for consuming the theme
 */
export declare function useTheme(): {
    spaces: {
        none: number;
        xs: string;
        sm: string;
        md: string;
        lg: string;
        xl: string;
    };
    zIndices: {
        sticky: number;
        fixed: number;
        overlay: number;
        modal: number;
        popover: number;
        tooltip: number;
    };
    breakpoints: {
        sm: string;
        md: string;
        lg: string;
        xl: string;
    };
    mediaQueries: {
        sm: string;
        md: string;
        lg: string;
        xl: string;
        hover: string;
    };
    fontSizes: {
        0: string;
        1: string;
        2: string;
        3: string;
        4: string;
        5: string;
        6: string;
        7: string;
        8: string;
        9: string;
    };
    radii: {
        sm: string;
        md: string;
        lg: string;
    };
    fonts: {
        sans: string;
        base: string;
        monospace: string;
    };
    shadows: {
        xs: string;
        sm: string;
        md: string;
        lg: string;
        xl: string;
    };
    lineHeights: {
        heading: number;
        body: number;
    };
    fontWeights: {
        body: number;
        heading: number;
        display: number;
    };
    iconSizes: {
        xs: string;
        sm: string;
        md: string;
        lg: string;
        xl: string;
    };
    outline: string;
    colors: {
        palette: import("./colors").PaletteType;
        scales: {
            gray: string[];
            blue: string[];
            green: string[];
            red: string[];
            orange: string[];
            yellow: string[];
            teal: string[];
            cyan: string[];
            lime: string[];
            pink: string[]; /**
             * Provide a theme to your app using React Context
             */
            violet: string[];
            indigo: string[];
        };
        intent: {
            none: {
                lightest: string;
                light: string;
                base: string;
                dark: string;
            };
            primary: {
                lightest: string;
                light: string;
                base: string;
                dark: string;
            };
            success: {
                lightest: string;
                light: string;
                base: string;
                dark: string;
            };
            danger: {
                lightest: string;
                light: string;
                base: string;
                dark: string;
            };
            warning: {
                lightest: string;
                light: string;
                base: string;
                dark: string;
            };
        };
        background: {
            tint1: string;
            tint2: string;
            overlay: string;
            layer: string;
            default: string;
        };
        border: {
            default: string;
            muted: string;
        };
        text: {
            heading: string;
            muted: string;
            default: string;
            selected: string;
        };
        shadows: {
            xs: string;
            sm: string;
            md: string;
            lg: string;
            xl: string;
        };
        mode: string;
    };
    modes: {
        light: {
            palette: import("./colors").PaletteType;
            scales: {
                gray: string[];
                blue: string[];
                green: string[];
                red: string[];
                orange: string[];
                yellow: string[];
                teal: string[];
                cyan: string[];
                lime: string[];
                pink: string[]; /**
                 * Provide a theme to your app using React Context
                 */
                violet: string[];
                indigo: string[];
            };
            intent: {
                none: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
                primary: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
                success: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
                danger: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
                warning: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
            };
            background: {
                tint1: string;
                tint2: string;
                overlay: string;
                layer: string;
                default: string;
            };
            border: {
                default: string;
                muted: string;
            };
            text: {
                heading: string;
                muted: string;
                default: string;
                selected: string;
            };
            shadows: {
                xs: string;
                sm: string;
                md: string;
                lg: string;
                xl: string;
            };
            mode: string;
        };
        dark: {
            palette: import("./colors").PaletteType;
            scales: {
                gray: string[];
                blue: string[];
                green: string[];
                red: string[];
                orange: string[];
                yellow: string[];
                teal: string[];
                cyan: string[];
                lime: string[];
                pink: string[]; /**
                 * Provide a theme to your app using React Context
                 */
                violet: string[];
                indigo: string[];
            };
            intent: {
                none: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
                primary: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
                success: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
                danger: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
                warning: {
                    lightest: string;
                    light: string;
                    base: string;
                    dark: string;
                };
            };
            background: {
                tint1: string;
                tint2: string;
                overlay: string;
                layer: string;
                default: string;
            };
            border: {
                default: string;
                muted: string;
            };
            text: {
                heading: string;
                muted: string;
                default: string;
                selected: string;
            };
            shadows: {
                xs: string;
                sm: string;
                md: string;
                lg: string;
                xl: string;
            };
            mode: string;
        };
    };
};
/**
 * Switch color modes (typically between light (default) and dark)
 */
declare type RenderCallbackType = (theme: Theme) => React.ReactNode;
export interface ColorModeProps {
    colors: ThemeColors;
    children: RenderCallbackType | React.ReactNode;
    ref: React.Ref<any>;
}
/**
 * Provide a light theme
 */
interface ModeProps {
    children: RenderCallbackType | React.ReactNode;
    ref?: any;
}
export declare const LightMode: React.RefForwardingComponent<React.Ref<any>, ModeProps>;
/**
 * Provide a dark theme
 */
export declare const DarkMode: React.RefForwardingComponent<React.Ref<any>, ModeProps>;
export {};
