import * as tslib_1 from "tslib";
import open from "open-color";
import color from "color";
import { createShadows, createDarkShadows } from "./shadows";
export function lighten(c, amount) {
    return color(c)
        .lighten(amount)
        .hsl()
        .string();
}
export function alpha(c, amount) {
    return color(c)
        .alpha(amount)
        .hsl()
        .string();
}
/**
 * normalize open-color to remove some colours,
 * such as 'grape'. This should be compatible with a tool
 * like palx.
 */
var defaultScales = {
    gray: open.gray,
    blue: open.blue,
    green: open.green,
    red: open.red,
    orange: open.orange,
    yellow: open.yellow,
    teal: open.teal,
    cyan: open.cyan,
    lime: open.lime,
    pink: open.pink,
    violet: open.violet,
    indigo: open.indigo
};
/**
 * Generate a palette from scales.
 *
 * `light` is typically used in dark mode for things like
 *  outline buttons, ghost buttons, etc.
 *
 * `base` is typically used for buttons, avatar colors, etc.
 *
 * @param scales
 */
function defaultGeneratePalette(scales) {
    return {
        gray: {
            lightest: scales.gray[1],
            light: scales.gray[4],
            base: scales.gray[8],
            dark: scales.gray[9]
        },
        blue: {
            lightest: scales.blue[1],
            light: scales.blue[5],
            base: scales.blue[8],
            dark: scales.blue[9]
        },
        red: {
            lightest: scales.red[1],
            light: scales.red[6],
            base: scales.red[8],
            dark: scales.red[9]
        },
        orange: {
            lightest: scales.orange[1],
            light: scales.orange[4],
            base: scales.orange[8],
            dark: scales.orange[9]
        },
        yellow: {
            lightest: scales.yellow[1],
            light: scales.yellow[4],
            base: scales.yellow[8],
            dark: scales.yellow[9]
        },
        green: {
            lightest: scales.green[1],
            light: scales.green[5],
            base: scales.green[8],
            dark: scales.green[9]
        },
        teal: {
            lightest: scales.teal[1],
            light: scales.teal[4],
            base: scales.teal[8],
            dark: scales.teal[9]
        },
        violet: {
            lightest: scales.violet[1],
            light: scales.violet[4],
            base: scales.violet[8],
            dark: scales.violet[9]
        }
    };
}
/**
 * Generate lightmode colors
 * @param scales
 * @param palette
 */
function defaultGenerateLightMode(scales, palette) {
    return {
        background: {
            tint1: scales.gray[1],
            tint2: scales.gray[3],
            overlay: alpha(scales.gray[9], 0.6),
            layer: "white",
            default: "white"
        },
        border: {
            default: alpha(scales.gray[9], 0.12),
            muted: alpha(scales.gray[9], 0.08)
        },
        text: {
            heading: scales.gray[9],
            muted: color(scales.gray[7])
                .lighten(0.3)
                .hex()
                .toString(),
            default: scales.gray[9],
            selected: palette.blue.base
        },
        shadows: createShadows(scales.gray[8])
    };
}
/**
 * Generate dark mode colors
 * @param scales
 * @param palette
 */
function defaultGenerateDarkMode(scales, palette) {
    var base = scales.gray[9];
    return {
        background: {
            tint1: lighten(base, 0.5),
            tint2: lighten(base, 0.7),
            overlay: alpha(scales.gray[7], 0.8),
            layer: lighten(base, 0.2),
            default: base
        },
        border: {
            default: alpha(scales.gray[0], 0.13),
            muted: alpha(scales.gray[0], 0.08)
        },
        text: {
            heading: "white",
            muted: "rgba(255,255,255,0.7)",
            default: "rgba(255,255,255,0.88)",
            selected: palette.blue.base
        },
        shadows: createDarkShadows("black")
    };
}
/**
 * Intents map a color palette to a particular intent (ie, primary, success)
 * @param palette
 */
function defaultGenerateIntents(palette) {
    return {
        none: palette.gray,
        primary: palette.blue,
        success: palette.green,
        danger: palette.red,
        warning: palette.yellow
    };
}
export function generateColorsFromScales(scales, generators) {
    if (generators === void 0) { generators = {}; }
    var _a = tslib_1.__assign({ generateIntents: defaultGenerateIntents, generatePalette: defaultGeneratePalette, generateLightMode: defaultGenerateLightMode, generateDarkMode: defaultGenerateDarkMode }, generators), generateIntents = _a.generateIntents, generatePalette = _a.generatePalette, generateLightMode = _a.generateLightMode, generateDarkMode = _a.generateDarkMode;
    var palette = generatePalette(scales);
    var intent = generateIntents(palette);
    var modes = {
        light: tslib_1.__assign({ mode: "light" }, generateLightMode(scales, palette), { palette: palette,
            scales: scales,
            intent: intent }),
        dark: tslib_1.__assign({ mode: "dark" }, generateDarkMode(scales, palette), { palette: palette,
            scales: scales,
            intent: intent })
    };
    return {
        colors: modes.light,
        modes: modes
    };
}
export var defaultColors = generateColorsFromScales(defaultScales);
