import * as React from "react";
import { OnPressFunction } from "touchable-hook";
/**
 * Touchable is a low level component which implements
 * the useTouchable hook. It provides consistent hover and
 * active styles on desktop and mobile devices.
 */
export interface TouchableProps {
    onPress?: OnPressFunction;
    disabled?: boolean;
    /** By default, a touchable element will only highlight after a short
     * delay to prevent unintended highlights when scrolling. This will
     * only effect touch devices. */
    delay?: number;
    /**
     * By default, a touchable element will have an expanded press area of 20px
     * on touch devices. This will only effect touch devices.
     */
    pressExpandPx?: number;
    /** Whether active presses should be terminated when scrolling occurs. Typically this should be true. */
    terminateOnScroll?: boolean;
    component?: React.ReactType<any>;
    [key: string]: any;
}
export declare const Touchable: React.RefForwardingComponent<React.Ref<any>, TouchableProps>;
