/** @jsx jsx */
import { jsx } from "@emotion/core";
import * as React from "react";
import { storiesOf } from "@storybook/react";
import { useInfiniteScroll } from "../Hooks/use-infinite-scroll";
import * as faker from "faker";
import { ScrollView } from "../ScrollView";
import { List, ListItem } from "../List";
import { Skeleton } from "../Skeleton";
import { Avatar } from "../Avatar";
import { Layer } from "../Layer";
import { IconChevronRight } from "../Icons";
import { useTheme } from "../Theme/Providers";
function fetchdata() {
    return new Promise(function (resolve) {
        setTimeout(function () {
            resolve();
        }, 800);
    });
}
function getUser() {
    faker.seed(0);
    return {
        name: faker.name.firstName() + " " + faker.name.lastName(),
        uid: faker.random.uuid(),
        description: faker.lorem.sentence()
    };
}
function Example() {
    var theme = useTheme();
    var ref = React.useRef(null);
    var _a = React.useState(Array.from(new Array(10)).map(function () { return getUser(); })), items = _a[0], setItems = _a[1];
    var _b = React.useState(0), page = _b[0], setPage = _b[1];
    var fetching = useInfiniteScroll({
        container: ref,
        hasMore: page < 4,
        onFetch: function () {
            return fetchdata().then(function () {
                setItems(items.concat(Array.from(new Array(10)).map(function () { return getUser(); })));
                setPage(page + 1);
            });
        }
    })[0];
    return (jsx(Layer, { css: {
            width: "400px",
            overflow: "hidden"
        } },
        jsx(ScrollView, { css: {
                height: "280px"
            }, overflowY: true, innerRef: ref },
            jsx(List, null,
                items.map(function (item) { return (jsx(ListItem, { key: item.uid, contentBefore: jsx(Avatar, { name: item.name }), primary: item.name, secondary: item.description, contentAfter: jsx(IconChevronRight, { color: theme.colors.text.muted }) })); }),
                fetching && (jsx(ListItem, { interactive: false, "aria-live": "polite", "aria-busy": "true", primary: jsx(Skeleton, { animated: true, css: { width: "100px" } }), secondary: jsx(Skeleton, { animated: true }), contentBefore: jsx(Skeleton, { animated: true, css: {
                            width: "3.27rem",
                            height: "3.27rem",
                            borderRadius: "50%"
                        } }) }))))));
}
function WindowExample() {
    var _a = React.useState(Array.from(new Array(10)).map(function () { return faker.name.firstName(); })), items = _a[0], setItems = _a[1];
    var _b = React.useState(0), page = _b[0], setPage = _b[1];
    var fetching = useInfiniteScroll({
        hasMore: page < 4,
        onFetch: function () {
            return fetchdata().then(function () {
                setItems(items.concat(Array.from(new Array(10)).map(function () { return faker.name.firstName(); })));
                setPage(page + 1);
            });
        }
    })[0];
    return (jsx("div", null,
        items.map(function (item) { return (jsx("div", { css: { height: "40px", border: "1px solid" }, key: item }, item)); }),
        fetching && jsx("div", null, "Loading...")));
}
export var ThemeExamples = storiesOf("InfiniteScroll", module)
    .add("Basic usage", function () { return (jsx("div", { css: { padding: "1rem" } },
    jsx(Example, null))); })
    .add("Window scroll", function () { return jsx(WindowExample, null); });
