/** @jsx jsx */
import { jsx } from "@emotion/core";
import theme from "../Theme";
import { storiesOf } from "@storybook/react";
import { Layer } from "../Layer";
import { Table, TableHead, TableCell, TableBody, TableRow, ExpandingRow } from "../Table";
import { Text } from "../Text";
import { Button } from "../Button";
import { Toolbar } from "../Toolbar";
var id = 0;
function createData(name, calories, fat, carbs, protein) {
    id += 1;
    return { id: id, name: name, calories: calories, fat: fat, carbs: carbs, protein: protein };
}
var rows = [
    createData("Frozen yoghurt", 159, 6.0, 24, 4.0),
    createData("Ice cream sandwich", 237, 9.0, 37, 4.3),
    createData("Eclair", 262, 16.0, 24, 6.0),
    createData("Cupcake", 305, 3.7, 67, 4.3),
    createData("Gingerbread", 356, 16.0, 49, 3.9)
];
export var TableExamples = storiesOf("Tables", module)
    .add("Minimum size with scroll", function () { return (jsx("div", { css: { padding: "48px" } },
    jsx(Table, { minWidth: "800px" },
        jsx(TableHead, null,
            jsx(TableRow, null,
                jsx(TableCell, null, "Dessert (100g serving)"),
                jsx(TableCell, { align: "right" }, "Calories"),
                jsx(TableCell, { align: "right" }, "Fat (g)"),
                jsx(TableCell, { align: "right" }, "Carbs (g)"),
                jsx(TableCell, { align: "right" }, "Protein (g)"))),
        jsx(TableBody, null, rows.map(function (row) { return (jsx(TableRow, { key: row.id },
            jsx(TableCell, { component: "th", scope: "row" }, row.name),
            jsx(TableCell, { align: "right" }, row.calories),
            jsx(TableCell, { align: "right" }, row.fat),
            jsx(TableCell, { align: "right" }, row.carbs),
            jsx(TableCell, { align: "right" }, row.protein))); }))))); })
    .add("Fixed layout", function () { return (jsx("div", { css: {
        minHeight: "100vh",
        background: theme.colors.background.tint2,
        padding: "48px"
    } },
    jsx(Layer, { elevation: "sm", css: { overflow: "hidden" } },
        jsx(Toolbar, { css: {
                borderBottom: "1px solid " + theme.colors.border.default,
                background: theme.colors.background.tint1,
                justifyContent: "space-between"
            } },
            jsx(Text, { css: { margin: 0 }, variant: "h4" }, "Ingredients"),
            jsx("div", null,
                jsx(Button, { intent: "primary" }, "Add ingredient"))),
        jsx(Table, { minWidth: "700px", fixed: ["200", "15%", "15%", "15%", "15%"] },
            jsx(TableHead, null,
                jsx(TableRow, null,
                    jsx(TableCell, null, "Dessert (100g serving)"),
                    jsx(TableCell, { align: "right" }, "Calories"),
                    jsx(TableCell, { align: "right" }, "Fat (g)"),
                    jsx(TableCell, { align: "right" }, "Carbs (g)"),
                    jsx(TableCell, { align: "right" }, "Protein (g)"))),
            jsx(TableBody, null,
                rows.map(function (row) { return (jsx(TableRow, { key: row.id },
                    jsx(TableCell, { component: "th", scope: "row" }, row.name),
                    jsx(TableCell, { align: "right" }, row.calories),
                    jsx(TableCell, { align: "right" }, row.fat),
                    jsx(TableCell, { align: "right" }, row.carbs),
                    jsx(TableCell, { align: "right" }, row.protein))); }),
                jsx(TableRow, null,
                    jsx(TableCell, { component: "th", scope: "row" }, "With a really really really stupidly long name"),
                    jsx(TableCell, { align: "right" }, "10"),
                    jsx(TableCell, { align: "right" }, "30"),
                    jsx(TableCell, { align: "right" }, "49"),
                    jsx(TableCell, { align: "right" }, "122")))),
        jsx(Toolbar, { compressed: true, css: {
                background: theme.colors.background.tint1
            } })))); })
    .add("Expanding rows", function () { return (jsx("div", { css: {
        minHeight: "100vh",
        background: theme.colors.background.tint2,
        padding: "48px"
    } },
    jsx(Layer, { elevation: "sm" },
        jsx(Toolbar, { css: {
                borderTopRightRadius: theme.radii.lg,
                borderTopLeftRadius: theme.radii.lg,
                borderBottom: "1px solid " + theme.colors.border.default,
                background: theme.colors.background.tint1,
                justifyContent: "space-between"
            } },
            jsx(Text, { css: { margin: 0 }, variant: "h4" }, "Ingredients"),
            jsx("div", null,
                jsx(Button, { intent: "primary" }, "Add ingredient"))),
        jsx(Table, { fixed: ["200", "15%", "15%", "15%", "15%"] },
            jsx(TableHead, null,
                jsx(TableRow, null,
                    jsx(TableCell, null, "Dessert (100g serving)"),
                    jsx(TableCell, { align: "right" }, "Calories"),
                    jsx(TableCell, { align: "right" }, "Fat (g)"),
                    jsx(TableCell, { align: "right" }, "Carbs (g)"),
                    jsx(TableCell, { align: "right" }, "Protein (g)"))),
            rows.map(function (row) { return (jsx(ExpandingRow, { content: function (close) {
                    return (jsx("div", { css: {
                            padding: theme.spaces.lg,
                            paddingTop: 0,
                            paddingBottom: 0
                        } },
                        jsx(Text, { variant: "body", css: { fontSize: theme.fontSizes[0] } }, "Officia laborum deserunt adipisicing reprehenderit esse elit exercitation consectetur ad non. Enim reprehenderit mollit in commodo anim ex consequat magna laboris adipisicing esse. Fugiat adipisicing ut consequat ea cupidatat et excepteur sint excepteur cupidatat reprehenderit minim. Labore reprehenderit sint enim cillum exercitation ullamco nisi nostrud laboris ad magna magna officia magna. Officia nisi eiusmod non ea do ullamco anim fugiat proident commodo consectetur ut id. Ea cillum non voluptate ullamco sunt dolore esse mollit."),
                        jsx("div", { css: {
                                display: "flex",
                                marginTop: "1rem",
                                justifyContent: "flex-end"
                            } },
                            jsx(Button, { variant: "ghost", css: { marginRight: theme.spaces.sm }, onClick: close }, "Cancel"),
                            jsx(Button, { intent: "primary" }, "Save"))));
                }, key: row.id },
                jsx(TableCell, { component: "th", scope: "row" }, row.name),
                jsx(TableCell, { align: "right" }, row.calories),
                jsx(TableCell, { align: "right" }, row.fat),
                jsx(TableCell, { align: "right" }, row.carbs),
                jsx(TableCell, { align: "right" }, row.protein))); })),
        jsx(Toolbar, { compressed: true, css: {
                borderBottomRightRadius: theme.radii.lg,
                borderBottomLeftRadius: theme.radii.lg,
                background: theme.colors.background.tint1
            } })))); });
